Class: DefinitionsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/clients/definitions_client.rb

Instance Method Summary collapse

Constructor Details

#initialize(connection) ⇒ DefinitionsClient

Initialize the DefinitionsClient class with an API client instance.

Parameters:

  • connection (LockstepApi)

    The API client object for this connection



22
23
24
# File 'lib/lockstep_sdk/clients/definitions_client.rb', line 22

def initialize(connection)
    @connection = connection
end

Instance Method Details

#query_countries(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object

Queries the ISO3166 List of Countries using the specified filtering, sorting, nested fetch, and pagination rules requested.

More information on querying can be found on the Searchlight Query Language page on the Lockstep Developer website.

Your program may want to show a list of countries. The ISO maintains a list of countries called ISO3166. For convenience, this list is available in the API.

Parameters:

  • filter (string)

    The filter for this query. See Searchlight Query Language

  • include_param (string)

    To fetch additional data on this object, specify the list of elements to retrieve. No collections are currently available, but may be offered in the future.

  • order (string)

    The sort order for this query. See See Searchlight Query Language

  • page_size (int32)

    The page size for results (default 250, maximum of 500). See Searchlight Query Language

  • page_number (int32)

    The page number for results (default 0). See Searchlight Query Language



38
39
40
41
42
# File 'lib/lockstep_sdk/clients/definitions_client.rb', line 38

def query_countries(filter:, include_param:, order:, page_size:, page_number:)
    path = "/api/v1/Definitions/countries"
    params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number}
    @connection.request(:get, path, nil, params)
end

#query_currencies(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object

Queries Currencies on the Lockstep Platform using the specified filtering, sorting, nested fetch, and pagination rules requested.

More information on querying can be found on the Searchlight Query Language page on the Lockstep Developer website.

Your app may wish to make use of a reference list that contains names and attributes for all ISO-4217 defined currency codes. This information is provided via a query endpoint so that you can use this API to provide a user selection screen.

Parameters:

  • filter (string)

    The filter for this query. See Searchlight Query Language

  • include_param (string)

    To fetch additional data on this object, specify the list of elements to retrieve. No collections are currently available, but may be offered in the future.

  • order (string)

    The sort order for this query. See See Searchlight Query Language

  • page_size (int32)

    The page size for results (default 250, maximum of 500). See Searchlight Query Language

  • page_number (int32)

    The page number for results (default 0). See Searchlight Query Language



55
56
57
58
59
# File 'lib/lockstep_sdk/clients/definitions_client.rb', line 55

def query_currencies(filter:, include_param:, order:, page_size:, page_number:)
    path = "/api/v1/Definitions/currencies"
    params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number}
    @connection.request(:get, path, nil, params)
end

#query_financial_systems(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object

Queries a list of financial systems using the specified filtering, sorting, nested fetch, and pagination rules requested.

More information on querying can be found on the Searchlight Query Language page on the Lockstep Developer website.

Lockstep provides a list of financial systems that may be useful as a selection screen that allows customers to select from a list. You can query these items by name or attributes and use this data source to help users complete a selection.

Parameters:

  • filter (string)

    The filter for this query. See Searchlight Query Language

  • include_param (string)

    To fetch additional data on this object, specify the list of elements to retrieve. No collections are currently available, but may be offered in the future.

  • order (string)

    The sort order for this query. See See Searchlight Query Language

  • page_size (int32)

    The page size for results (default 250, maximum of 500). See Searchlight Query Language

  • page_number (int32)

    The page number for results (default 0). See Searchlight Query Language



89
90
91
92
93
# File 'lib/lockstep_sdk/clients/definitions_client.rb', line 89

def query_financial_systems(filter:, include_param:, order:, page_size:, page_number:)
    path = "/api/v1/Definitions/financialsystems"
    params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number}
    @connection.request(:get, path, nil, params)
end

#query_states(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object

Queries the list of States in the United States using the specified filtering, sorting, nested fetch, and pagination rules requested.

More information on querying can be found on the Searchlight Query Language page on the Lockstep Developer website.

Your app may wish to make use of a reference list that contains names and codes for all states in the United States. This information is provided for the United States since many financial systems require mailing addresses that use codes for states.

Parameters:

  • filter (string)

    The filter for this query. See Searchlight Query Language

  • include_param (string)

    To fetch additional data on this object, specify the list of elements to retrieve. No collections are currently available, but may be offered in the future.

  • order (string)

    The sort order for this query. See See Searchlight Query Language

  • page_size (int32)

    The page size for results (default 250, maximum of 500). See Searchlight Query Language

  • page_number (int32)

    The page number for results (default 0). See Searchlight Query Language



72
73
74
75
76
# File 'lib/lockstep_sdk/clients/definitions_client.rb', line 72

def query_states(filter:, include_param:, order:, page_size:, page_number:)
    path = "/api/v1/Definitions/states"
    params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number}
    @connection.request(:get, path, nil, params)
end