Class: FinancialInstitutionAccountsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/clients/financial_institution_accounts_client.rb

Instance Method Summary collapse

Constructor Details

#initialize(connection) ⇒ FinancialInstitutionAccountsClient

Initialize the FinancialInstitutionAccountsClient class with an API client instance.

Parameters:

  • connection (LockstepApi) —

    The API client object for this connection



22
23
24
# File 'lib/lockstep_sdk/clients/financial_institution_accounts_client.rb', line 22

def initialize(connection)
    @connection = connection
end

Instance Method Details

#query_financial_institution_accounts(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object

Parameters:

  • filter (string) —

    The filter for this query. See Searchlight Query Language

  • include_param (string) —

    To fetch additional data on this object, specify the list of elements to retrieve. No collections are currently available but may be offered in the future.

  • order (string) —

    The sort order for this query. See See Searchlight Query Language

  • page_size (int32) —

    The page size for results (default 250, maximum of 500). See Searchlight Query Language

  • page_number (int32) —

    The page number for results (default 0). See Searchlight Query Language



44
45
46
47
48
# File 'lib/lockstep_sdk/clients/financial_institution_accounts_client.rb', line 44

def query_financial_institution_accounts(filter:, include_param:, order:, page_size:, page_number:)
    path = "/api/v1/financial-institution-accounts/query"
    params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number}
    @connection.request(:get, path, nil, params)
end

#retrieve_financial_institution_accounts(id:) ⇒ Object

Retrieves the financial institution account specified by this unique identifier.

Parameters:

  • id (uuid) —

    The unique Lockstep Platform ID number of this institution account; NOT the customer's ERP key



31
32
33
34
# File 'lib/lockstep_sdk/clients/financial_institution_accounts_client.rb', line 31

def retrieve_financial_institution_accounts(id:)
    path = "/api/v1/financial-institution-accounts/#{id}"
    @connection.request(:get, path, nil, nil)
end