Class: LockstepSdk::AccountingProfileContactModel
- Inherits:
-
Object
- Object
- LockstepSdk::AccountingProfileContactModel
- Defined in:
- lib/lockstep_sdk/models/accounting_profile_contact_model.rb
Overview
An Accounting Profile Contact has a link to a Contact that is associated with your company's Accounting Profile. These Contacts are secondary contacts to the primary that is on the profile.
Instance Attribute Summary collapse
-
#accounting_profile_contact_id ⇒ Uuid
The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.
-
#accounting_profile_id ⇒ Uuid
The ID of the profile this contact is belongs to.
-
#contact_id ⇒ Uuid
The ID of the contact that is linked to this profile.
-
#created ⇒ Date-time
The date on which this record was created.
-
#created_user_id ⇒ Uuid
The ID of the user who created this contact.
-
#group_key ⇒ Uuid
The GroupKey uniquely identifies a single Lockstep Platform account.
-
#is_primary ⇒ Boolean
Determines whether the contact is primary or secondary.
-
#modified ⇒ Date-time
The date on which this record was last modified.
-
#modified_user_id ⇒ Uuid
The ID of the user who last modified this contact.
Instance Method Summary collapse
-
#as_json(options = {}) ⇒ object
This object as a JSON key-value structure.
-
#initialize(params = {}) ⇒ AccountingProfileContactModel
constructor
Initialize the AccountingProfileContactModel using the provided prototype.
-
#to_json(*options) ⇒ String
This object converted to a JSON string.
Constructor Details
#initialize(params = {}) ⇒ AccountingProfileContactModel
Initialize the AccountingProfileContactModel using the provided prototype
26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 26 def initialize(params = {}) @accounting_profile_contact_id = params.dig(:accounting_profile_contact_id) @accounting_profile_id = params.dig(:accounting_profile_id) @contact_id = params.dig(:contact_id) @is_primary = params.dig(:is_primary) @group_key = params.dig(:group_key) @created = params.dig(:created) @created_user_id = params.dig(:created_user_id) @modified = params.dig(:modified) @modified_user_id = params.dig(:modified_user_id) end |
Instance Attribute Details
#accounting_profile_contact_id ⇒ Uuid
Returns The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.
40 41 42 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 40 def accounting_profile_contact_id @accounting_profile_contact_id end |
#accounting_profile_id ⇒ Uuid
Returns The ID of the profile this contact is belongs to.
44 45 46 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 44 def accounting_profile_id @accounting_profile_id end |
#contact_id ⇒ Uuid
Returns The ID of the contact that is linked to this profile.
48 49 50 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 48 def contact_id @contact_id end |
#created ⇒ Date-time
Returns The date on which this record was created.
60 61 62 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 60 def created @created end |
#created_user_id ⇒ Uuid
Returns The ID of the user who created this contact.
64 65 66 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 64 def created_user_id @created_user_id end |
#group_key ⇒ Uuid
Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.
56 57 58 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 56 def group_key @group_key end |
#is_primary ⇒ Boolean
Returns Determines whether the contact is primary or secondary.
52 53 54 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 52 def is_primary @is_primary end |
#modified ⇒ Date-time
Returns The date on which this record was last modified.
68 69 70 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 68 def modified @modified end |
#modified_user_id ⇒ Uuid
Returns The ID of the user who last modified this contact.
72 73 74 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 72 def modified_user_id @modified_user_id end |
Instance Method Details
#as_json(options = {}) ⇒ object
Returns This object as a JSON key-value structure.
76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 76 def as_json(={}) { 'accountingProfileContactId' => @accounting_profile_contact_id, 'accountingProfileId' => @accounting_profile_id, 'contactId' => @contact_id, 'isPrimary' => @is_primary, 'groupKey' => @group_key, 'created' => @created, 'createdUserId' => @created_user_id, 'modified' => @modified, 'modifiedUserId' => @modified_user_id, } end |
#to_json(*options) ⇒ String
Returns This object converted to a JSON string.
92 93 94 |
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 92 def to_json(*) "[#{as_json(*).to_json(*)}]" end |