Class: LockstepSdk::ActivityModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/activity_model.rb

Overview

An Activity contains information about work being done on a specific accounting task. You can use Activities to track information about who has been assigned a specific task, the current status of the task, the name and description given for the particular task, the priority of the task, and any amounts collected, paid, or credited for the task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ ActivityModel

Initialize the ActivityModel using the provided prototype



28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/lockstep_sdk/models/activity_model.rb', line 28

def initialize(params = {})
    @activity_id = params.dig(:activity_id)
    @group_key = params.dig(:group_key)
    @company_id = params.dig(:company_id)
    @activity_type_code = params.dig(:activity_type_code)
    @activity_name = params.dig(:activity_name)
    @activity_description = params.dig(:activity_description)
    @activity_status = params.dig(:activity_status)
    @is_open = params.dig(:is_open)
    @priority = params.dig(:priority)
    @user_assigned_to = params.dig(:user_assigned_to)
    @date_assigned = params.dig(:date_assigned)
    @date_closed = params.dig(:date_closed)
    @snooze_until_date = params.dig(:snooze_until_date)
    @created = params.dig(:created)
    @created_user_id = params.dig(:created_user_id)
    @modified = params.dig(:modified)
    @modified_user_id = params.dig(:modified_user_id)
    @amount_collected = params.dig(:amount_collected)
    @amount_paid = params.dig(:amount_paid)
    @credit_given = params.dig(:credit_given)
    @is_unread = params.dig(:is_unread)
    @is_archived = params.dig(:is_archived)
    @company = params.dig(:company)
    @user_assigned_to_name = params.dig(:user_assigned_to_name)
    @attachments = params.dig(:attachments)
    @notes = params.dig(:notes)
    @custom_field_definitions = params.dig(:custom_field_definitions)
    @custom_field_values = params.dig(:custom_field_values)
    @references = params.dig(:references)
end

Instance Attribute Details

#activity_descriptionString

Returns A description of the activity. This field contains more detailed text about the activity and can be lengthy.

Returns:

  • (String)

    A description of the activity. This field contains more detailed text about the activity and can be lengthy.



82
83
84
# File 'lib/lockstep_sdk/models/activity_model.rb', line 82

def activity_description
  @activity_description
end

#activity_idUuid

Returns The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.

Returns:

  • (Uuid)

    The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.



62
63
64
# File 'lib/lockstep_sdk/models/activity_model.rb', line 62

def activity_id
  @activity_id
end

#activity_nameString

Returns The name of the activity. The name is a short name provided by the person who created the activity that can be displayed in a list.

Returns:

  • (String)

    The name of the activity. The name is a short name provided by the person who created the activity that can be displayed in a list.



78
79
80
# File 'lib/lockstep_sdk/models/activity_model.rb', line 78

def activity_name
  @activity_name
end

#activity_statusString

Returns The status of the activity.

Returns:

  • (String)

    The status of the activity.



86
87
88
# File 'lib/lockstep_sdk/models/activity_model.rb', line 86

def activity_status
  @activity_status
end

#activity_type_codeString

Returns The type code of the activity.

Returns:

  • (String)

    The type code of the activity



74
75
76
# File 'lib/lockstep_sdk/models/activity_model.rb', line 74

def activity_type_code
  @activity_type_code
end

#amount_collectedDouble

Returns Amount collected (if any) for the activity.

Returns:

  • (Double)

    Amount collected (if any) for the activity.



130
131
132
# File 'lib/lockstep_sdk/models/activity_model.rb', line 130

def amount_collected
  @amount_collected
end

#amount_paidDouble

Returns Amount paid (if any) for the activity.

Returns:

  • (Double)

    Amount paid (if any) for the activity.



134
135
136
# File 'lib/lockstep_sdk/models/activity_model.rb', line 134

def amount_paid
  @amount_paid
end

#attachmentsAttachmentModel

Returns A collection of attachments linked to this record. To retrieve this collection, specify Attachments in the include parameter when retrieving data. To create an attachment, use the [Upload Attachment](developer.lockstep.io/reference/post_api-v1-attachments) endpoint with the TableKey to Activity and the ObjectKey set to the ActivityId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



158
159
160
# File 'lib/lockstep_sdk/models/activity_model.rb', line 158

def attachments
  @attachments
end

#companyCompanyModel

Returns The company associated with the activity To retrieve this collection, specify Company in the “Include” parameter for your query.

Returns:

  • (CompanyModel)

    The company associated with the activity To retrieve this collection, specify Company in the “Include” parameter for your query.



150
151
152
# File 'lib/lockstep_sdk/models/activity_model.rb', line 150

def company
  @company
end

#company_idUuid

Returns The ID of the company to which this activity belongs.

Returns:

  • (Uuid)

    The ID of the company to which this activity belongs.



70
71
72
# File 'lib/lockstep_sdk/models/activity_model.rb', line 70

def company_id
  @company_id
end

#createdDate-time

Returns The date on which this activity was created.

Returns:

  • (Date-time)

    The date on which this activity was created.



114
115
116
# File 'lib/lockstep_sdk/models/activity_model.rb', line 114

def created
  @created
end

#created_user_idUuid

Returns The ID of the user who created this activity.

Returns:

  • (Uuid)

    The ID of the user who created this activity.



118
119
120
# File 'lib/lockstep_sdk/models/activity_model.rb', line 118

def created_user_id
  @created_user_id
end

#credit_givenDouble

Returns Credit given (if any) for the activity.

Returns:

  • (Double)

    Credit given (if any) for the activity.



138
139
140
# File 'lib/lockstep_sdk/models/activity_model.rb', line 138

def credit_given
  @credit_given
end

#custom_field_definitionsCustomFieldDefinitionModel

Returns A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldDefinitions in the include parameter when retrieving data. To create a custom field, use the [Create Custom Field](developer.lockstep.io/reference/post_api-v1-customfieldvalues) endpoint with the TableKey to Activity and the ObjectKey set to the ActivityId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



166
167
168
# File 'lib/lockstep_sdk/models/activity_model.rb', line 166

def custom_field_definitions
  @custom_field_definitions
end

#custom_field_valuesCustomFieldValueModel

Returns A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldValues in the include parameter when retrieving data. To create a custom field, use the [Create Custom Field](developer.lockstep.io/reference/post_api-v1-customfieldvalues) endpoint with the TableKey to Activity and the ObjectKey set to the ActivityId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



170
171
172
# File 'lib/lockstep_sdk/models/activity_model.rb', line 170

def custom_field_values
  @custom_field_values
end

#date_assignedDate-time

Returns The date the activity was assigned.

Returns:

  • (Date-time)

    The date the activity was assigned.



102
103
104
# File 'lib/lockstep_sdk/models/activity_model.rb', line 102

def date_assigned
  @date_assigned
end

#date_closedDate-time

Returns The date the activity was closed.

Returns:

  • (Date-time)

    The date the activity was closed.



106
107
108
# File 'lib/lockstep_sdk/models/activity_model.rb', line 106

def date_closed
  @date_closed
end

#group_keyUuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).

Returns:

  • (Uuid)

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).



66
67
68
# File 'lib/lockstep_sdk/models/activity_model.rb', line 66

def group_key
  @group_key
end

#is_archivedBoolean

Returns Activities may be archived when they should be hidden from the user. When this flag is true, this activity should be hidden.

Returns:

  • (Boolean)

    Activities may be archived when they should be hidden from the user. When this flag is true, this activity should be hidden.



146
147
148
# File 'lib/lockstep_sdk/models/activity_model.rb', line 146

def is_archived
  @is_archived
end

#is_openBoolean

Returns True if this activity is currently “open”, which indicates that the activity is currently in progress.

Returns:

  • (Boolean)

    True if this activity is currently “open”, which indicates that the activity is currently in progress.



90
91
92
# File 'lib/lockstep_sdk/models/activity_model.rb', line 90

def is_open
  @is_open
end

#is_unreadBoolean

Returns True if this activity is to be shown in an “unread” state. When an activity is read by a person it is assigned to, this flag is set to false.

Returns:

  • (Boolean)

    True if this activity is to be shown in an “unread” state. When an activity is read by a person it is assigned to, this flag is set to false.



142
143
144
# File 'lib/lockstep_sdk/models/activity_model.rb', line 142

def is_unread
  @is_unread
end

#modifiedDate-time

Returns The date on which this activity was last modified.

Returns:

  • (Date-time)

    The date on which this activity was last modified.



122
123
124
# File 'lib/lockstep_sdk/models/activity_model.rb', line 122

def modified
  @modified
end

#modified_user_idUuid

Returns The ID of the user who last modified this activity.

Returns:

  • (Uuid)

    The ID of the user who last modified this activity.



126
127
128
# File 'lib/lockstep_sdk/models/activity_model.rb', line 126

def modified_user_id
  @modified_user_id
end

#notesNoteModel

Returns A collection of notes linked to this record. To retrieve this collection, specify Notes in the include parameter when retrieving data. To create a note, use the [Create Note](developer.lockstep.io/reference/post_api-v1-notes) endpoint with the TableKey to Activity and the ObjectKey set to the ActivityId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



162
163
164
# File 'lib/lockstep_sdk/models/activity_model.rb', line 162

def notes
  @notes
end

#priorityString

Returns The priority of the activity.

Returns:

  • (String)

    The priority of the activity.



94
95
96
# File 'lib/lockstep_sdk/models/activity_model.rb', line 94

def priority
  @priority
end

#referencesActivityXRefModel

Returns All references attached to this applied activity. To retrieve this collection, specify References in the “Include” parameter for your query.

Returns:

  • (ActivityXRefModel)

    All references attached to this applied activity. To retrieve this collection, specify References in the “Include” parameter for your query.



174
175
176
# File 'lib/lockstep_sdk/models/activity_model.rb', line 174

def references
  @references
end

#snooze_until_dateDate-time

Returns If this activity has been “snoozed”, this field will be non-null and will contain the date when the activity will be displayed. Until that date arrives, the activity will remain hidden.

Returns:

  • (Date-time)

    If this activity has been “snoozed”, this field will be non-null and will contain the date when the activity will be displayed. Until that date arrives, the activity will remain hidden.



110
111
112
# File 'lib/lockstep_sdk/models/activity_model.rb', line 110

def snooze_until_date
  @snooze_until_date
end

#user_assigned_toUuid

Returns The ID of the user the activity is assigned to.

Returns:

  • (Uuid)

    The ID of the user the activity is assigned to.



98
99
100
# File 'lib/lockstep_sdk/models/activity_model.rb', line 98

def user_assigned_to
  @user_assigned_to
end

#user_assigned_to_nameString

Returns The name of the user the activity is assigned to.

Returns:

  • (String)

    The name of the user the activity is assigned to



154
155
156
# File 'lib/lockstep_sdk/models/activity_model.rb', line 154

def user_assigned_to_name
  @user_assigned_to_name
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object)

    This object as a JSON key-value structure



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/lockstep_sdk/models/activity_model.rb', line 178

def as_json(options={})
    {
        'activityId' => @activity_id,
        'groupKey' => @group_key,
        'companyId' => @company_id,
        'activityTypeCode' => @activity_type_code,
        'activityName' => @activity_name,
        'activityDescription' => @activity_description,
        'activityStatus' => @activity_status,
        'isOpen' => @is_open,
        'priority' => @priority,
        'userAssignedTo' => @user_assigned_to,
        'dateAssigned' => @date_assigned,
        'dateClosed' => @date_closed,
        'snoozeUntilDate' => @snooze_until_date,
        'created' => @created,
        'createdUserId' => @created_user_id,
        'modified' => @modified,
        'modifiedUserId' => @modified_user_id,
        'amountCollected' => @amount_collected,
        'amountPaid' => @amount_paid,
        'creditGiven' => @credit_given,
        'isUnread' => @is_unread,
        'isArchived' => @is_archived,
        'company' => @company,
        'userAssignedToName' => @user_assigned_to_name,
        'attachments' => @attachments,
        'notes' => @notes,
        'customFieldDefinitions' => @custom_field_definitions,
        'customFieldValues' => @custom_field_values,
        'references' => @references,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String)

    This object converted to a JSON string



214
215
216
# File 'lib/lockstep_sdk/models/activity_model.rb', line 214

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end