Class: LockstepSdk::ApAgingHeaderInfoModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/ap_aging_header_info_model.rb

Overview

Aggregated Accounts Payable Aging information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ ApAgingHeaderInfoModel

Initialize the ApAgingHeaderInfoModel using the provided prototype



25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 25

def initialize(params = {})
    @group_key = params.dig(:group_key)
    @report_bucket = params.dig(:report_bucket)
    @total_vendors = params.dig(:total_vendors)
    @total_bills_outstanding = params.dig(:total_bills_outstanding)
    @total_bills_outstanding_amount = params.dig(:total_bills_outstanding_amount)
    @total_credit_memo_outstanding_amount = params.dig(:total_credit_memo_outstanding_amount)
    @total_advance_payment_amount = params.dig(:total_advance_payment_amount)
    @total_outstanding_amount = params.dig(:total_outstanding_amount)
    @total_ap_amount = params.dig(:total_ap_amount)
    @percentage_of_total_ap = params.dig(:percentage_of_total_ap)
end

Instance Attribute Details

#group_key ⇒ Uuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.

Returns:

  • (Uuid) —

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.



40
41
42
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 40

def group_key
  @group_key
end

#percentage_of_total_ap ⇒ Double

Returns Portion of Total AP this data represents.

Returns:

  • (Double) —

    Portion of Total AP this data represents.



76
77
78
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 76

def percentage_of_total_ap
  @percentage_of_total_ap
end

#report_bucket ⇒ String

Returns The aging bucket this data belongs to.

Returns:

  • (String) —

    The aging bucket this data belongs to.



44
45
46
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 44

def report_bucket
  @report_bucket
end

#total_advance_payment_amount ⇒ Double

Returns The total amount of advance payments.

Returns:

  • (Double) —

    The total amount of advance payments.



64
65
66
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 64

def total_advance_payment_amount
  @total_advance_payment_amount
end

#total_ap_amount ⇒ Double

Returns The total amount for AP.

Returns:

  • (Double) —

    The total amount for AP.



72
73
74
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 72

def total_ap_amount
  @total_ap_amount
end

#total_bills_outstanding ⇒ Int32

Returns The total number of bills outstanding.

Returns:

  • (Int32) —

    The total number of bills outstanding.



52
53
54
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 52

def total_bills_outstanding
  @total_bills_outstanding
end

#total_bills_outstanding_amount ⇒ Double

Returns The total amount outstanding on bills.

Returns:

  • (Double) —

    The total amount outstanding on bills.



56
57
58
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 56

def total_bills_outstanding_amount
  @total_bills_outstanding_amount
end

#total_credit_memo_outstanding_amount ⇒ Double

Returns The total amount outstanding on credit memos.

Returns:

  • (Double) —

    The total amount outstanding on credit memos.



60
61
62
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 60

def total_credit_memo_outstanding_amount
  @total_credit_memo_outstanding_amount
end

#total_outstanding_amount ⇒ Double

Returns The total amount outstanding.

Returns:

  • (Double) —

    The total amount outstanding.



68
69
70
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 68

def total_outstanding_amount
  @total_outstanding_amount
end

#total_vendors ⇒ Int32

Returns The total number of vendors.

Returns:

  • (Int32) —

    The total number of vendors.



48
49
50
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 48

def total_vendors
  @total_vendors
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object) —

    This object as a JSON key-value structure



80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 80

def as_json(options={})
    {
        'groupKey' => @group_key,
        'reportBucket' => @report_bucket,
        'totalVendors' => @total_vendors,
        'totalBillsOutstanding' => @total_bills_outstanding,
        'totalBillsOutstandingAmount' => @total_bills_outstanding_amount,
        'totalCreditMemoOutstandingAmount' => @total_credit_memo_outstanding_amount,
        'totalAdvancePaymentAmount' => @total_advance_payment_amount,
        'totalOutstandingAmount' => @total_outstanding_amount,
        'totalApAmount' => @total_ap_amount,
        'percentageOfTotalAp' => @percentage_of_total_ap,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String) —

    This object converted to a JSON string



97
98
99
# File 'lib/lockstep_sdk/models/ap_aging_header_info_model.rb', line 97

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end