Class: LockstepSdk::ApplicationModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/application_model.rb

Overview

An Application represents a feature available to customers within the Lockstep Platform. You can create Applications by working with your Lockstep business development manager and publish them on the platform so that customers can browse and find your Application on the Lockstep Platform Marketplace. When a customer adds an Application to their account, they obtain an AppEnrollment which represents that customer's instance of this Application. The customer-specific AppEnrollment contains a customer's configuration data for the Application, which is not customer-specific.

See Applications and Enrollments for more information. --swaggerCategory:Platform

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ ApplicationModel

Initialize the ApplicationModel using the provided prototype



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/lockstep_sdk/models/application_model.rb', line 33

def initialize(params = {})
    @app_id = params.dig(:app_id)
    @name = params.dig(:name)
    @description = params.dig(:description)
    @app_type = params.dig(:app_type)
    @owner_id = params.dig(:owner_id)
    @project_url = params.dig(:project_url)
    @icon_url = params.dig(:icon_url)
    @created_user_id = params.dig(:created_user_id)
    @modified_user_id = params.dig(:modified_user_id)
    @created = params.dig(:created)
    @modified = params.dig(:modified)
    @is_active = params.dig(:is_active)
    @group_key = params.dig(:group_key)
    @b2_cclient_id = params.dig(:b2_cclient_id)
    @notes = params.dig(:notes)
    @attachments = params.dig(:attachments)
    @custom_field_definitions = params.dig(:custom_field_definitions)
    @custom_field_values = params.dig(:custom_field_values)
end

Instance Attribute Details

#app_id ⇒ Uuid

Returns A unique code identifying this application.

Returns:

  • (Uuid) —

    A unique code identifying this application



56
57
58
# File 'lib/lockstep_sdk/models/application_model.rb', line 56

def app_id
  @app_id
end

#app_type ⇒ String

Returns Tag for what type of app this is.

Returns:

  • (String) —

    Tag for what type of app this is



68
69
70
# File 'lib/lockstep_sdk/models/application_model.rb', line 68

def app_type
  @app_type
end

#attachments ⇒ AttachmentModel

Returns A collection of attachments linked to this record. To retrieve this collection, specify Attachments in the include parameter when retrieving data. To create an attachment, use the Upload Attachment endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see linking extensible metadata to objects.

Returns:

  • (AttachmentModel) —

    A collection of attachments linked to this record. To retrieve this collection, specify Attachments in the include parameter when retrieving data. To create an attachment, use the Upload Attachment endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see linking extensible metadata to objects.



116
117
118
# File 'lib/lockstep_sdk/models/application_model.rb', line 116

def attachments
  @attachments
end

#b2_cclient_id ⇒ Uuid

Returns The B2C Client ID of the application.

Returns:

  • (Uuid) —

    The B2C Client ID of the application



108
109
110
# File 'lib/lockstep_sdk/models/application_model.rb', line 108

def b2_cclient_id
  @b2_cclient_id
end

#created ⇒ Date-time

Returns The date this application was created.

Returns:

  • (Date-time) —

    The date this application was created



92
93
94
# File 'lib/lockstep_sdk/models/application_model.rb', line 92

def created
  @created
end

#created_user_id ⇒ Uuid

Returns The ID of the user who created this application.

Returns:

  • (Uuid) —

    The ID of the user who created this application



84
85
86
# File 'lib/lockstep_sdk/models/application_model.rb', line 84

def created_user_id
  @created_user_id
end

#custom_field_definitions ⇒ CustomFieldDefinitionModel

Returns A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldDefinitions in the include parameter when retrieving data. To create a custom field, use the Create Custom Field endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see linking extensible metadata to objects.

Returns:

  • (CustomFieldDefinitionModel) —

    A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldDefinitions in the include parameter when retrieving data. To create a custom field, use the Create Custom Field endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see linking extensible metadata to objects.



120
121
122
# File 'lib/lockstep_sdk/models/application_model.rb', line 120

def custom_field_definitions
  @custom_field_definitions
end

#custom_field_values ⇒ CustomFieldValueModel

Returns A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldValues in the include parameter when retrieving data. To create a custom field, use the Create Custom Field endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see linking extensible metadata to objects.

Returns:

  • (CustomFieldValueModel) —

    A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldValues in the include parameter when retrieving data. To create a custom field, use the Create Custom Field endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see linking extensible metadata to objects.



124
125
126
# File 'lib/lockstep_sdk/models/application_model.rb', line 124

def custom_field_values
  @custom_field_values
end

#description ⇒ String

Returns Brief summary of this application shown as a subtitle.

Returns:

  • (String) —

    Brief summary of this application shown as a subtitle



64
65
66
# File 'lib/lockstep_sdk/models/application_model.rb', line 64

def description
  @description
end

#group_key ⇒ Uuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.

Returns:

  • (Uuid) —

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.



104
105
106
# File 'lib/lockstep_sdk/models/application_model.rb', line 104

def group_key
  @group_key
end

#icon_url ⇒ String

Returns The URL for the icon for this application.

Returns:

  • (String) —

    The URL for the icon for this application



80
81
82
# File 'lib/lockstep_sdk/models/application_model.rb', line 80

def icon_url
  @icon_url
end

#is_active ⇒ Boolean

Returns Flag indicating if the application is active.

Returns:

  • (Boolean) —

    Flag indicating if the application is active.



100
101
102
# File 'lib/lockstep_sdk/models/application_model.rb', line 100

def is_active
  @is_active
end

#modified ⇒ Date-time

Returns The date this application was last modified.

Returns:

  • (Date-time) —

    The date this application was last modified



96
97
98
# File 'lib/lockstep_sdk/models/application_model.rb', line 96

def modified
  @modified
end

#modified_user_id ⇒ Uuid

Returns The ID of the user who last modified this application.

Returns:

  • (Uuid) —

    The ID of the user who last modified this application



88
89
90
# File 'lib/lockstep_sdk/models/application_model.rb', line 88

def modified_user_id
  @modified_user_id
end

#name ⇒ String

Returns The name of this application.

Returns:

  • (String) —

    The name of this application



60
61
62
# File 'lib/lockstep_sdk/models/application_model.rb', line 60

def name
  @name
end

#notes ⇒ NoteModel

Returns A collection of notes linked to this record. To retrieve this collection, specify Notes in the include parameter when retrieving data. To create a note, use the Create Note endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see linking extensible metadata to objects.

Returns:

  • (NoteModel) —

    A collection of notes linked to this record. To retrieve this collection, specify Notes in the include parameter when retrieving data. To create a note, use the Create Note endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see linking extensible metadata to objects.



112
113
114
# File 'lib/lockstep_sdk/models/application_model.rb', line 112

def notes
  @notes
end

#owner_id ⇒ Uuid

Returns The ID of the owner.

Returns:

  • (Uuid) —

    The ID of the owner



72
73
74
# File 'lib/lockstep_sdk/models/application_model.rb', line 72

def owner_id
  @owner_id
end

#project_url ⇒ String

Returns The URL to visit for more information about this application.

Returns:

  • (String) —

    The URL to visit for more information about this application



76
77
78
# File 'lib/lockstep_sdk/models/application_model.rb', line 76

def project_url
  @project_url
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object) —

    This object as a JSON key-value structure



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/lockstep_sdk/models/application_model.rb', line 128

def as_json(options={})
    {
        'appId' => @app_id,
        'name' => @name,
        'description' => @description,
        'appType' => @app_type,
        'ownerId' => @owner_id,
        'projectUrl' => @project_url,
        'iconUrl' => @icon_url,
        'createdUserId' => @created_user_id,
        'modifiedUserId' => @modified_user_id,
        'created' => @created,
        'modified' => @modified,
        'isActive' => @is_active,
        'groupKey' => @group_key,
        'b2CClientId' => @b2_cclient_id,
        'notes' => @notes,
        'attachments' => @attachments,
        'customFieldDefinitions' => @custom_field_definitions,
        'customFieldValues' => @custom_field_values,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String) —

    This object converted to a JSON string



153
154
155
# File 'lib/lockstep_sdk/models/application_model.rb', line 153

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end