Class: LockstepSdk::ArAgingHeaderInfoModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/ar_aging_header_info_model.rb

Overview

Aggregated Accounts Receivable Aging information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ ArAgingHeaderInfoModel

Initialize the ArAgingHeaderInfoModel using the provided prototype



25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 25

def initialize(params = {})
    @group_key = params.dig(:group_key)
    @report_bucket = params.dig(:report_bucket)
    @total_customers = params.dig(:total_customers)
    @total_invoices_outstanding = params.dig(:total_invoices_outstanding)
    @total_invoice_outstanding_amount = params.dig(:total_invoice_outstanding_amount)
    @total_credit_memo_outstanding_amount = params.dig(:total_credit_memo_outstanding_amount)
    @total_unapplied_payment_amount = params.dig(:total_unapplied_payment_amount)
    @total_outstanding_amount = params.dig(:total_outstanding_amount)
    @total_ar_amount = params.dig(:total_ar_amount)
    @percentage_of_total_ar = params.dig(:percentage_of_total_ar)
end

Instance Attribute Details

#group_key ⇒ Uuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.

Returns:

  • (Uuid) —

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.



40
41
42
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 40

def group_key
  @group_key
end

#percentage_of_total_ar ⇒ Double

Returns Portion of Total AR this data represents.

Returns:

  • (Double) —

    Portion of Total AR this data represents.



76
77
78
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 76

def percentage_of_total_ar
  @percentage_of_total_ar
end

#report_bucket ⇒ String

Returns The aging bucket this data belongs to.

Returns:

  • (String) —

    The aging bucket this data belongs to.



44
45
46
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 44

def report_bucket
  @report_bucket
end

#total_ar_amount ⇒ Double

Returns The total amount for AR.

Returns:

  • (Double) —

    The total amount for AR.



72
73
74
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 72

def total_ar_amount
  @total_ar_amount
end

#total_credit_memo_outstanding_amount ⇒ Double

Returns The total amount outstanding on credit memos.

Returns:

  • (Double) —

    The total amount outstanding on credit memos.



60
61
62
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 60

def total_credit_memo_outstanding_amount
  @total_credit_memo_outstanding_amount
end

#total_customers ⇒ Int32

Returns The total number of customers.

Returns:

  • (Int32) —

    The total number of customers.



48
49
50
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 48

def total_customers
  @total_customers
end

#total_invoice_outstanding_amount ⇒ Double

Returns The total amount outstanding on invoices.

Returns:

  • (Double) —

    The total amount outstanding on invoices.



56
57
58
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 56

def total_invoice_outstanding_amount
  @total_invoice_outstanding_amount
end

#total_invoices_outstanding ⇒ Int32

Returns The total number of invoices outstanding.

Returns:

  • (Int32) —

    The total number of invoices outstanding.



52
53
54
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 52

def total_invoices_outstanding
  @total_invoices_outstanding
end

#total_outstanding_amount ⇒ Double

Returns The total amount outstanding.

Returns:

  • (Double) —

    The total amount outstanding.



68
69
70
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 68

def total_outstanding_amount
  @total_outstanding_amount
end

#total_unapplied_payment_amount ⇒ Double

Returns The total amount of unapplied payments.

Returns:

  • (Double) —

    The total amount of unapplied payments.



64
65
66
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 64

def total_unapplied_payment_amount
  @total_unapplied_payment_amount
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object) —

    This object as a JSON key-value structure



80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 80

def as_json(options={})
    {
        'groupKey' => @group_key,
        'reportBucket' => @report_bucket,
        'totalCustomers' => @total_customers,
        'totalInvoicesOutstanding' => @total_invoices_outstanding,
        'totalInvoiceOutstandingAmount' => @total_invoice_outstanding_amount,
        'totalCreditMemoOutstandingAmount' => @total_credit_memo_outstanding_amount,
        'totalUnappliedPaymentAmount' => @total_unapplied_payment_amount,
        'totalOutstandingAmount' => @total_outstanding_amount,
        'totalArAmount' => @total_ar_amount,
        'percentageOfTotalAr' => @percentage_of_total_ar,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String) —

    This object converted to a JSON string



97
98
99
# File 'lib/lockstep_sdk/models/ar_aging_header_info_model.rb', line 97

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end