Class: LockstepSdk::CompanyDetailsPaymentModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/company_details_payment_model.rb

Overview

Company payment collected information

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ CompanyDetailsPaymentModel

Initialize the CompanyDetailsPaymentModel using the provided prototype



25
26
27
28
29
30
31
32
33
34
35
36
37
38
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 25

def initialize(params = {})
    @group_key = params.dig(:group_key)
    @payment_id = params.dig(:payment_id)
    @payment_applied_id = params.dig(:payment_applied_id)
    @payment_type = params.dig(:payment_type)
    @invoice_id = params.dig(:invoice_id)
    @invoice_type_code = params.dig(:invoice_type_code)
    @invoice_reference_code = params.dig(:invoice_reference_code)
    @invoice_currency_code = params.dig(:invoice_currency_code)
    @invoice_total_amount = params.dig(:invoice_total_amount)
    @payment_date = params.dig(:payment_date)
    @payment_currency_code = params.dig(:payment_currency_code)
    @payment_amount = params.dig(:payment_amount)
end

Instance Attribute Details

#group_key ⇒ Uuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.

Returns:

  • (Uuid) —

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.



42
43
44
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 42

def group_key
  @group_key
end

#invoice_currency_code ⇒ String

Returns The currency code of the invoice the payment is associated with.

Returns:

  • (String) —

    The currency code of the invoice the payment is associated with.



70
71
72
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 70

def invoice_currency_code
  @invoice_currency_code
end

#invoice_id ⇒ Uuid

Returns Unique identifier for invoice payment is associated with.

Returns:

  • (Uuid) —

    Unique identifier for invoice payment is associated with



58
59
60
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 58

def invoice_id
  @invoice_id
end

#invoice_reference_code ⇒ String

Returns Invoice reference code payment is associated with.

Returns:

  • (String) —

    Invoice reference code payment is associated with



66
67
68
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 66

def invoice_reference_code
  @invoice_reference_code
end

#invoice_total_amount ⇒ Double

Returns Invoice total amount payment is associated with.

Returns:

  • (Double) —

    Invoice total amount payment is associated with



74
75
76
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 74

def invoice_total_amount
  @invoice_total_amount
end

#invoice_type_code ⇒ String

Returns Invoice type payment is associated with.

Returns:

  • (String) —

    Invoice type payment is associated with



62
63
64
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 62

def invoice_type_code
  @invoice_type_code
end

#payment_amount ⇒ Double

Returns Amount payment was made for.

Returns:

  • (Double) —

    Amount payment was made for



86
87
88
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 86

def payment_amount
  @payment_amount
end

#payment_applied_id ⇒ Uuid

Returns Unique identifier for payment applied.

Returns:

  • (Uuid) —

    Unique identifier for payment applied



50
51
52
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 50

def payment_applied_id
  @payment_applied_id
end

#payment_currency_code ⇒ String

Returns The currency code of the payment.

Returns:

  • (String) —

    The currency code of the payment.



82
83
84
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 82

def payment_currency_code
  @payment_currency_code
end

#payment_date ⇒ Date-time

Returns Date payment placed.

Returns:

  • (Date-time) —

    Date payment placed



78
79
80
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 78

def payment_date
  @payment_date
end

#payment_id ⇒ Uuid

Returns Unique identifier for payment.

Returns:

  • (Uuid) —

    Unique identifier for payment



46
47
48
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 46

def payment_id
  @payment_id
end

#payment_type ⇒ String

Returns Payment type.

Returns:

  • (String) —

    Payment type



54
55
56
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 54

def payment_type
  @payment_type
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object) —

    This object as a JSON key-value structure



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 90

def as_json(options={})
    {
        'groupKey' => @group_key,
        'paymentId' => @payment_id,
        'paymentAppliedId' => @payment_applied_id,
        'paymentType' => @payment_type,
        'invoiceId' => @invoice_id,
        'invoiceTypeCode' => @invoice_type_code,
        'invoiceReferenceCode' => @invoice_reference_code,
        'invoiceCurrencyCode' => @invoice_currency_code,
        'invoiceTotalAmount' => @invoice_total_amount,
        'paymentDate' => @payment_date,
        'paymentCurrencyCode' => @payment_currency_code,
        'paymentAmount' => @payment_amount,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String) —

    This object converted to a JSON string



109
110
111
# File 'lib/lockstep_sdk/models/company_details_payment_model.rb', line 109

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end