Class: LockstepSdk::CustomFieldValueModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/custom_field_value_model.rb

Overview

A Custom Field represents metadata added to an object within the Lockstep Platform. Lockstep provides a core definition for each object. The core definition is intended to represent a level of compatibility that provides support across most accounting systems and products. When a user or developer requires information beyond this core definition, you can use Custom Fields to represent this information.

See [Extensibility](developer.lockstep.io/docs/extensibility) for more information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ CustomFieldValueModel

Initialize the CustomFieldValueModel using the provided prototype



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 32

def initialize(params = {})
    @group_key = params.dig(:group_key)
    @custom_field_definition_id = params.dig(:custom_field_definition_id)
    @record_key = params.dig(:record_key)
    @string_value = params.dig(:string_value)
    @numeric_value = params.dig(:numeric_value)
    @created = params.dig(:created)
    @created_user_id = params.dig(:created_user_id)
    @modified = params.dig(:modified)
    @modified_user_id = params.dig(:modified_user_id)
    @app_enrollment_id = params.dig(:app_enrollment_id)
    @value = params.dig(:value)
    @custom_field_definition = params.dig(:custom_field_definition)
end

Instance Attribute Details

#app_enrollment_idUuid

Returns The AppEnrollmentId of the application that imported this attachment record. For accounts with more than one financial system connected, this field identifies the originating financial system that produced this record. This value is null if this record was not loaded from an external ERP or financial system.

Returns:

  • (Uuid)

    The AppEnrollmentId of the application that imported this attachment record. For accounts with more than one financial system connected, this field identifies the originating financial system that produced this record. This value is null if this record was not loaded from an external ERP or financial system.



85
86
87
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 85

def app_enrollment_id
  @app_enrollment_id
end

#createdDate-time

Returns Date created.

Returns:

  • (Date-time)

    Date created



69
70
71
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 69

def created
  @created
end

#created_user_idUuid

Returns Id of user who created this value.

Returns:

  • (Uuid)

    Id of user who created this value



73
74
75
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 73

def created_user_id
  @created_user_id
end

#custom_field_definitionCustomFieldDefinitionModel

Returns Definition of the value.

Returns:



93
94
95
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 93

def custom_field_definition
  @custom_field_definition
end

#custom_field_definition_idUuid

Returns The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.

Returns:

  • (Uuid)

    The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.



53
54
55
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 53

def custom_field_definition_id
  @custom_field_definition_id
end

#group_keyUuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).

Returns:

  • (Uuid)

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).



49
50
51
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 49

def group_key
  @group_key
end

#modifiedDate-time

Returns Date modified.

Returns:

  • (Date-time)

    Date modified



77
78
79
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 77

def modified
  @modified
end

#modified_user_idUuid

Returns Id of user who modified this value.

Returns:

  • (Uuid)

    Id of user who modified this value



81
82
83
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 81

def modified_user_id
  @modified_user_id
end

#numeric_valueDouble

Returns Number data for field.

Returns:

  • (Double)

    Number data for field



65
66
67
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 65

def numeric_value
  @numeric_value
end

#record_keyUuid

Returns Additional key if source table doesn’t have a unique id.

Returns:

  • (Uuid)

    Additional key if source table doesn’t have a unique id



57
58
59
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 57

def record_key
  @record_key
end

#string_valueString

Returns String of data for field.

Returns:

  • (String)

    String of data for field



61
62
63
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 61

def string_value
  @string_value
end

#valueString

Returns The value of this custom field.

Returns:

  • (String)

    The value of this custom field.



89
90
91
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 89

def value
  @value
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object)

    This object as a JSON key-value structure



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 97

def as_json(options={})
    {
        'groupKey' => @group_key,
        'customFieldDefinitionId' => @custom_field_definition_id,
        'recordKey' => @record_key,
        'stringValue' => @string_value,
        'numericValue' => @numeric_value,
        'created' => @created,
        'createdUserId' => @created_user_id,
        'modified' => @modified,
        'modifiedUserId' => @modified_user_id,
        'appEnrollmentId' => @app_enrollment_id,
        'value' => @value,
        'customFieldDefinition' => @custom_field_definition,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String)

    This object converted to a JSON string



116
117
118
# File 'lib/lockstep_sdk/models/custom_field_value_model.rb', line 116

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end