Class: LockstepSdk::FinancialInstitutionAccountModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/financial_institution_account_model.rb

Overview

An Financial Institution Account represents an account used for monetary transactions. E.g. - checking, savings, or credit card accounts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ FinancialInstitutionAccountModel

Initialize the FinancialInstitutionAccountModel using the provided prototype



25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 25

def initialize(params = {})
    @financial_institution_account_id = params.dig(:financial_institution_account_id)
    @group_key = params.dig(:group_key)
    @bank_account_id = params.dig(:bank_account_id)
    @erp_key = params.dig(:erp_key)
    @app_enrollment_id = params.dig(:app_enrollment_id)
    @name = params.dig(:name)
    @status = params.dig(:status)
    @description = params.dig(:description)
    @account_type = params.dig(:account_type)
    @created = params.dig(:created)
    @created_user_id = params.dig(:created_user_id)
    @modified = params.dig(:modified)
    @modified_user_id = params.dig(:modified_user_id)
end

Instance Attribute Details

#account_type ⇒ String

Returns The classification for the Financial Institution Account. Possible values are Asset, Equity, Expense, Liability or Income.

Returns:

  • (String) —

    The classification for the Financial Institution Account. Possible values are Asset, Equity, Expense, Liability or Income.



75
76
77
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 75

def 
  @account_type
end

#app_enrollment_id ⇒ Uuid

Returns The App Enrollment Id this Financial Institution is associated with.

Returns:

  • (Uuid) —

    The App Enrollment Id this Financial Institution is associated with.



59
60
61
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 59

def app_enrollment_id
  @app_enrollment_id
end

#bank_account_id ⇒ String

Returns An alternate account id for the Financial Institution Account.

Returns:

  • (String) —

    An alternate account id for the Financial Institution Account.



51
52
53
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 51

def 
  @bank_account_id
end

#created ⇒ Date-time

Returns The date the Financial Institution Account was created.

Returns:

  • (Date-time) —

    The date the Financial Institution Account was created.



79
80
81
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 79

def created
  @created
end

#created_user_id ⇒ Uuid

Returns The user that has created the Financial Institution Account.

Returns:

  • (Uuid) —

    The user that has created the Financial Institution Account.



83
84
85
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 83

def created_user_id
  @created_user_id
end

#description ⇒ String

Returns The description for the Financial Institution Account.

Returns:

  • (String) —

    The description for the Financial Institution Account.



71
72
73
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 71

def description
  @description
end

#erp_key ⇒ String

Returns The External Id for the Financial Institution Account.

Returns:

  • (String) —

    The External Id for the Financial Institution Account.



55
56
57
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 55

def erp_key
  @erp_key
end

#financial_institution_account_id ⇒ Uuid

Returns The unique identifier for the Financial Institution Account.

Returns:

  • (Uuid) —

    The unique identifier for the Financial Institution Account.



43
44
45
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 43

def 
  @financial_institution_account_id
end

#group_key ⇒ Uuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.

Returns:

  • (Uuid) —

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.



47
48
49
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 47

def group_key
  @group_key
end

#modified ⇒ Date-time

Returns The date the Financial Institution Account was modified.

Returns:

  • (Date-time) —

    The date the Financial Institution Account was modified.



87
88
89
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 87

def modified
  @modified
end

#modified_user_id ⇒ Uuid

Returns The user that has modified the Financial Institution Account.

Returns:

  • (Uuid) —

    The user that has modified the Financial Institution Account.



91
92
93
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 91

def modified_user_id
  @modified_user_id
end

#name ⇒ String

Returns The name of the Financial Institution Account.

Returns:

  • (String) —

    The name of the Financial Institution Account.



63
64
65
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 63

def name
  @name
end

#status ⇒ String

Returns The status of the Financial Institution Account. Possible values are active, inactive, deleted or archived.

Returns:

  • (String) —

    The status of the Financial Institution Account. Possible values are active, inactive, deleted or archived.



67
68
69
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 67

def status
  @status
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object) —

    This object as a JSON key-value structure



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 95

def as_json(options={})
    {
        'financialInstitutionAccountId' => @financial_institution_account_id,
        'groupKey' => @group_key,
        'bankAccountId' => @bank_account_id,
        'erpKey' => @erp_key,
        'appEnrollmentId' => @app_enrollment_id,
        'name' => @name,
        'status' => @status,
        'description' => @description,
        'accountType' => @account_type,
        'created' => @created,
        'createdUserId' => @created_user_id,
        'modified' => @modified,
        'modifiedUserId' => @modified_user_id,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String) —

    This object converted to a JSON string



115
116
117
# File 'lib/lockstep_sdk/models/financial_institution_account_model.rb', line 115

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end