Class: LockstepSdk::SyncRequestModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/sync_request_model.rb

Overview

Represents a Sync action that loads data from a connector into the Lockstep Platform. Users can request Sync actions manually using Lockstep Inbox, or via the [Create Sync API](developer.lockstep.io/reference/post_api-v1-sync). Each Sync action is tied to an [AppEnrollment](developer.lockstep.io/docs/applications-and-enrollments). When the Sync action is complete, the field StatusCode will be set to either Success or Failed.

You can fetch a list of detailed results for the Sync API by calling Retrieve or Query with an include parameter of details. These detailed results contain line-by-line errors that were detected during processing of this sync.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ SyncRequestModel

Initialize the SyncRequestModel using the provided prototype



32
33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 32

def initialize(params = {})
    @sync_request_id = params.dig(:sync_request_id)
    @group_key = params.dig(:group_key)
    @status_code = params.dig(:status_code)
    @operation_type_name = params.dig(:operation_type_name)
    @operation_type = params.dig(:operation_type)
    @process_result_message = params.dig(:process_result_message)
    @run_full_sync = params.dig(:run_full_sync)
    @app_enrollment_id = params.dig(:app_enrollment_id)
    @created = params.dig(:created)
    @modified = params.dig(:modified)
    @modified_user_id = params.dig(:modified_user_id)
    @details = params.dig(:details)
end

Instance Attribute Details

#app_enrollment_idUuid

Returns The AppEnrollmentId of the AppEnrollment object that executed this sync request.

Returns:

  • (Uuid)

    The AppEnrollmentId of the AppEnrollment object that executed this sync request



77
78
79
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 77

def app_enrollment_id
  @app_enrollment_id
end

#createdDate-time

Returns The date this sync request was created.

Returns:

  • (Date-time)

    The date this sync request was created



81
82
83
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 81

def created
  @created
end

#detailsObject

Returns The detailed list of results and errors that occurred during the processing of this SyncRequest. This information is available only after the SyncRequest has completed. You will only be able to fetch this field if the SyncRequest’s StatusCode field is set to Cancelled, Success, or Failed. To retrieve this collection, add the keyword details to the include parameter on your Retrieve or Query requests.

Returns:

  • (Object)

    The detailed list of results and errors that occurred during the processing of this SyncRequest. This information is available only after the SyncRequest has completed. You will only be able to fetch this field if the SyncRequest’s StatusCode field is set to Cancelled, Success, or Failed. To retrieve this collection, add the keyword details to the include parameter on your Retrieve or Query requests.



93
94
95
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 93

def details
  @details
end

#group_keyUuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).

Returns:

  • (Uuid)

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).



53
54
55
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 53

def group_key
  @group_key
end

#modifiedDate-time

Returns The date this sync request was last modified.

Returns:

  • (Date-time)

    The date this sync request was last modified



85
86
87
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 85

def modified
  @modified
end

#modified_user_idUuid

Returns The ID number of the user who most recently modified this sync request.

Returns:

  • (Uuid)

    The ID number of the user who most recently modified this sync request.



89
90
91
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 89

def modified_user_id
  @modified_user_id
end

#operation_typeInt32

Returns The name of the OperationType for this SyncRequest.

Returns:

  • (Int32)

    The name of the OperationType for this SyncRequest



65
66
67
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 65

def operation_type
  @operation_type
end

#operation_type_nameString

Returns The name of the OperationType for this SyncRequest.

Returns:

  • (String)

    The name of the OperationType for this SyncRequest



61
62
63
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 61

def operation_type_name
  @operation_type_name
end

#process_result_messageString

Returns Message containing information about the sync request results.

Returns:

  • (String)

    Message containing information about the sync request results



69
70
71
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 69

def process_result_message
  @process_result_message
end

#run_full_syncString

Returns A boolean indicating whether a sync from an ERP system should process all the data from the ERP as opposed to just the delta of changes since the previous sync run.

Returns:

  • (String)

    A boolean indicating whether a sync from an ERP system should process all the data from the ERP as opposed to just the delta of changes since the previous sync run



73
74
75
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 73

def run_full_sync
  @run_full_sync
end

#status_codeString

Returns The status of processing for this SyncRequest. When a SyncRequest is created, it is flagged as Ready. When it is picked up for execution, its status moves to ‘In Progress`. When it is complete, its status will move to Success or Failed. If another API call cancels the SyncRequest, its status will move to Cancelled. * Ready * In Progress * Cancelled * Failed * Success.

Returns:

  • (String)

    The status of processing for this SyncRequest. When a SyncRequest is created, it is flagged as Ready. When it is picked up for execution, its status moves to ‘In Progress`. When it is complete, its status will move to Success or Failed. If another API call cancels the SyncRequest, its status will move to Cancelled. * Ready * In Progress * Cancelled * Failed * Success



57
58
59
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 57

def status_code
  @status_code
end

#sync_request_idUuid

Returns The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.

Returns:

  • (Uuid)

    The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.



49
50
51
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 49

def sync_request_id
  @sync_request_id
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object)

    This object as a JSON key-value structure



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 97

def as_json(options={})
    {
        'syncRequestId' => @sync_request_id,
        'groupKey' => @group_key,
        'statusCode' => @status_code,
        'operationTypeName' => @operation_type_name,
        'operationType' => @operation_type,
        'processResultMessage' => @process_result_message,
        'runFullSync' => @run_full_sync,
        'appEnrollmentId' => @app_enrollment_id,
        'created' => @created,
        'modified' => @modified,
        'modifiedUserId' => @modified_user_id,
        'details' => @details,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String)

    This object converted to a JSON string



116
117
118
# File 'lib/lockstep_sdk/models/sync_request_model.rb', line 116

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end