Class: NotesClient
- Inherits:
-
Object
- Object
- NotesClient
- Defined in:
- lib/lockstep_sdk/clients/notes_client.rb
Instance Method Summary collapse
-
#archive_note(id:) ⇒ Object
Archives the Note with the unique ID specified.
-
#create_notes(body:) ⇒ Object
Creates one or more notes from the specified array of Note Models.
-
#initialize(connection) ⇒ NotesClient
constructor
Initialize the NotesClient class with an API client instance.
-
#query_notes(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object
Queries Notes on the Lockstep Platform using the specified filtering, sorting, nested fetch, and pagination rules requested.
-
#retrieve_note(id:, include_param:) ⇒ Object
Retrieves the note with the specified note identifier.
Constructor Details
#initialize(connection) ⇒ NotesClient
Initialize the NotesClient class with an API client instance.
22 23 24 |
# File 'lib/lockstep_sdk/clients/notes_client.rb', line 22 def initialize(connection) @connection = connection end |
Instance Method Details
#archive_note(id:) ⇒ Object
Archives the Note with the unique ID specified.
A note is a customizable text string that can be attached to various account attributes within Lockstep. You can use notes for internal communication, correspondence with clients, or personal reminders. The Note Model represents a note and a number of different metadata attributes related to the creation, storage, and ownership of the note.
See Extensibility for more information.
50 51 52 53 |
# File 'lib/lockstep_sdk/clients/notes_client.rb', line 50 def archive_note(id:) path = "/api/v1/Notes/#{id}" @connection.request(:delete, path, nil, nil) end |
#create_notes(body:) ⇒ Object
Creates one or more notes from the specified array of Note Models
A note is a customizable text string that can be attached to various account attributes within Lockstep. You can use notes for internal communication, correspondence with clients, or personal reminders. The Note Model represents a note and a number of different metadata attributes related to the creation, storage, and ownership of the note.
See Extensibility for more information.
63 64 65 66 |
# File 'lib/lockstep_sdk/clients/notes_client.rb', line 63 def create_notes(body:) path = "/api/v1/Notes" @connection.request(:post, path, body, nil) end |
#query_notes(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object
Queries Notes on the Lockstep Platform using the specified filtering, sorting, nested fetch, and pagination rules requested.
More information on querying can be found on the Searchlight Query Language page on the Lockstep Developer website.
A note is a customizable text string that can be attached to various account attributes within Lockstep. You can use notes for internal communication, correspondence with clients, or personal reminders. The Note Model represents a note and a number of different metadata attributes related to the creation, storage, and ownership of the note.
See Extensibility for more information.
82 83 84 85 86 |
# File 'lib/lockstep_sdk/clients/notes_client.rb', line 82 def query_notes(filter:, include_param:, order:, page_size:, page_number:) path = "/api/v1/Notes/query" params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number} @connection.request(:get, path, nil, params) end |
#retrieve_note(id:, include_param:) ⇒ Object
Retrieves the note with the specified note identifier.
A note is a customizable text string that can be attached to various account attributes within Lockstep. You can use notes for internal communication, correspondence with clients, or personal reminders. The Note Model represents a note and a number of different metadata attributes related to the creation, storage, and ownership of the note.
See Extensibility for more information.
36 37 38 39 40 |
# File 'lib/lockstep_sdk/clients/notes_client.rb', line 36 def retrieve_note(id:, include_param:) path = "/api/v1/Notes/#{id}" params = {:include => include_param} @connection.request(:get, path, nil, params) end |