Class: UserRolesClient

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/clients/user_roles_client.rb

Instance Method Summary collapse

Constructor Details

#initialize(connection) ⇒ UserRolesClient

Initialize the UserRolesClient class with an API client instance.

Parameters:

  • connection (LockstepApi) —

    The API client object for this connection



22
23
24
# File 'lib/lockstep_sdk/clients/user_roles_client.rb', line 22

def initialize(connection)
    @connection = connection
end

Instance Method Details

#query_user_roles(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object

Queries User Roles for this account using the specified filtering, sorting, nested fetch, and pagination rules requested.

Parameters:

  • filter (string) —

    The filter for this query. See Searchlight Query Language

  • include_param (string) —

    To fetch additional data on this object, specify the list of elements to retrieve. No collections are currently available but may be offered in the future

  • order (string) —

    The sort order for this query. See See Searchlight Query Language

  • page_size (int32) —

    The page size for results (default 250, maximum of 500). See Searchlight Query Language

  • page_number (int32) —

    The page number for results (default 0). See Searchlight Query Language



46
47
48
49
50
# File 'lib/lockstep_sdk/clients/user_roles_client.rb', line 46

def query_user_roles(filter:, include_param:, order:, page_size:, page_number:)
    path = "/api/v1/UserRoles/query"
    params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number}
    @connection.request(:get, path, nil, params)
end

#retrieve_user_role(id:, include_param:) ⇒ Object

Retrieves the User Role with this identifier.

Parameters:

  • id (uuid) —

    The unique ID number of the User Role to retrieve

  • include_param (string) —

    To fetch additional data on this object, specify the list of elements to retrieve. No collections are currently available but may be offered in the future



32
33
34
35
36
# File 'lib/lockstep_sdk/clients/user_roles_client.rb', line 32

def retrieve_user_role(id:, include_param:)
    path = "/api/v1/UserRoles/#{id}"
    params = {:include => include_param}
    @connection.request(:get, path, nil, params)
end