Class: AttachmentLinksClient
- Inherits:
-
Object
- Object
- AttachmentLinksClient
- Defined in:
- lib/lockstep_sdk/clients/attachment_links_client.rb
Instance Method Summary collapse
-
#delete_attachment_link(attachment_id:, object_key:, table_name:) ⇒ Object
Delete the specified link between an object and its attachment.
-
#initialize(connection) ⇒ AttachmentLinksClient
constructor
Initialize the AttachmentLinksClient class with an API client instance.
-
#query_attachment_links(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object
Queries Attachment Links for this account using the specified filtering, sorting, nested fetch, and pagination rules requested.
-
#retrieve_attachment_link(attachment_id:, object_key:, table_name:) ⇒ Object
Retrieves the Attachment Link with the provided Attachment Link identifier.
-
#upload_attachment(body:) ⇒ Object
Creates one Attachment Link from the provided arguments.
Constructor Details
#initialize(connection) ⇒ AttachmentLinksClient
Initialize the AttachmentLinksClient class with an API client instance.
22 23 24 |
# File 'lib/lockstep_sdk/clients/attachment_links_client.rb', line 22 def initialize(connection) @connection = connection end |
Instance Method Details
#delete_attachment_link(attachment_id:, object_key:, table_name:) ⇒ Object
Delete the specified link between an object and its attachment.
An Attachment Link is a link that associates one Attachment with one object within Lockstep.
See Extensibility for more information.
66 67 68 69 70 |
# File 'lib/lockstep_sdk/clients/attachment_links_client.rb', line 66 def (attachment_id:, object_key:, table_name:) path = "/api/v1/AttachmentLinks" params = {:attachmentId => , :objectKey => object_key, :tableName => table_name} @connection.request(:delete, path, nil, params) end |
#query_attachment_links(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object
Queries Attachment Links for this account using the specified filtering, sorting, nested fetch, and pagination rules requested.
More information on querying can be found on the Searchlight Query Language page on the Lockstep Developer website.
An Attachment Link is a link that associates one Attachment with one object within Lockstep.
See Extensibility for more information.
86 87 88 89 90 |
# File 'lib/lockstep_sdk/clients/attachment_links_client.rb', line 86 def (filter:, include_param:, order:, page_size:, page_number:) path = "/api/v1/AttachmentLinks/query" params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number} @connection.request(:get, path, nil, params) end |
#retrieve_attachment_link(attachment_id:, object_key:, table_name:) ⇒ Object
Retrieves the Attachment Link with the provided Attachment Link identifier.
An Attachment Link is a link that associates one Attachment with one object within Lockstep.
See Extensibility for more information.
37 38 39 40 41 |
# File 'lib/lockstep_sdk/clients/attachment_links_client.rb', line 37 def (attachment_id:, object_key:, table_name:) path = "/api/v1/AttachmentLinks" params = {:attachmentId => , :objectKey => object_key, :tableName => table_name} @connection.request(:get, path, nil, params) end |
#upload_attachment(body:) ⇒ Object
Creates one Attachment Link from the provided arguments.
An Attachment Link is a link that associates one Attachment with one object within Lockstep.
See Extensibility for more information.
51 52 53 54 |
# File 'lib/lockstep_sdk/clients/attachment_links_client.rb', line 51 def (body:) path = "/api/v1/AttachmentLinks" @connection.request(:post, path, body, nil) end |