Class: LockstepSdk::AccountingProfileContactModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/accounting_profile_contact_model.rb

Overview

An Accounting Profile Contact has a link to a Contact that is associated with your company’s Accounting Profile. These Contacts are secondary contacts to the primary that is on the profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ AccountingProfileContactModel

Initialize the AccountingProfileContactModel using the provided prototype



26
27
28
29
30
31
32
33
34
35
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 26

def initialize(params = {})
    @accounting_profile_contact_id = params.dig(:accounting_profile_contact_id)
    @accounting_profile_id = params.dig(:accounting_profile_id)
    @contact_id = params.dig(:contact_id)
    @group_key = params.dig(:group_key)
    @created = params.dig(:created)
    @created_user_id = params.dig(:created_user_id)
    @modified = params.dig(:modified)
    @modified_user_id = params.dig(:modified_user_id)
end

Instance Attribute Details

#accounting_profile_contact_idUuid

Returns The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.

Returns:

  • (Uuid)

    The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform.



39
40
41
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 39

def accounting_profile_contact_id
  @accounting_profile_contact_id
end

#accounting_profile_idUuid

Returns The ID of the profile this contact is belongs to.

Returns:

  • (Uuid)

    The ID of the profile this contact is belongs to.



43
44
45
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 43

def accounting_profile_id
  @accounting_profile_id
end

#contact_idUuid

Returns The ID of the contact that is linked to this profile.

Returns:

  • (Uuid)

    The ID of the contact that is linked to this profile.



47
48
49
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 47

def contact_id
  @contact_id
end

#createdDate-time

Returns The date on which this record was created.

Returns:

  • (Date-time)

    The date on which this record was created.



55
56
57
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 55

def created
  @created
end

#created_user_idUuid

Returns The ID of the user who created this contact.

Returns:

  • (Uuid)

    The ID of the user who created this contact.



59
60
61
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 59

def created_user_id
  @created_user_id
end

#group_keyUuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).

Returns:

  • (Uuid)

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).



51
52
53
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 51

def group_key
  @group_key
end

#modifiedDate-time

Returns The date on which this record was last modified.

Returns:

  • (Date-time)

    The date on which this record was last modified.



63
64
65
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 63

def modified
  @modified
end

#modified_user_idUuid

Returns The ID of the user who last modified this contact.

Returns:

  • (Uuid)

    The ID of the user who last modified this contact.



67
68
69
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 67

def modified_user_id
  @modified_user_id
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object)

    This object as a JSON key-value structure



71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 71

def as_json(options={})
    {
        'accountingProfileContactId' => @accounting_profile_contact_id,
        'accountingProfileId' => @accounting_profile_id,
        'contactId' => @contact_id,
        'groupKey' => @group_key,
        'created' => @created,
        'createdUserId' => @created_user_id,
        'modified' => @modified,
        'modifiedUserId' => @modified_user_id,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String)

    This object converted to a JSON string



86
87
88
# File 'lib/lockstep_sdk/models/accounting_profile_contact_model.rb', line 86

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end