Class: LockstepSdk::AppEnrollmentReconnectInfo
- Inherits:
-
Object
- Object
- LockstepSdk::AppEnrollmentReconnectInfo
- Defined in:
- lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb
Overview
Information to reconnect an ERP.
Instance Attribute Summary collapse
-
#auth_code ⇒ String
The OAuth authentication code.
-
#password ⇒ String
The password for the web services account with access permissions.
-
#realm_id ⇒ String
The Realm Id for the app enrollment to reconnect.
-
#token_id ⇒ String
The access token id for the connector enrollment.
-
#token_secret ⇒ String
The access token secret for the connector enrollment.
-
#username ⇒ String
The OAuth authentication code.
Instance Method Summary collapse
-
#as_json(options = {}) ⇒ object
This object as a JSON key-value structure.
-
#initialize(params = {}) ⇒ AppEnrollmentReconnectInfo
constructor
Initialize the AppEnrollmentReconnectInfo using the provided prototype.
-
#to_json(*options) ⇒ String
This object converted to a JSON string.
Constructor Details
#initialize(params = {}) ⇒ AppEnrollmentReconnectInfo
Initialize the AppEnrollmentReconnectInfo using the provided prototype
25 26 27 28 29 30 31 32 |
# File 'lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb', line 25 def initialize(params = {}) @auth_code = params.dig(:auth_code) @username = params.dig(:username) @password = params.dig(:password) @realm_id = params.dig(:realm_id) @token_id = params.dig(:token_id) @token_secret = params.dig(:token_secret) end |
Instance Attribute Details
#auth_code ⇒ String
Returns The OAuth authentication code.
36 37 38 |
# File 'lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb', line 36 def auth_code @auth_code end |
#password ⇒ String
Returns The password for the web services account with access permissions.
44 45 46 |
# File 'lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb', line 44 def password @password end |
#realm_id ⇒ String
Returns The Realm Id for the app enrollment to reconnect.
48 49 50 |
# File 'lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb', line 48 def realm_id @realm_id end |
#token_id ⇒ String
Returns The access token id for the connector enrollment.
52 53 54 |
# File 'lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb', line 52 def token_id @token_id end |
#token_secret ⇒ String
Returns The access token secret for the connector enrollment.
56 57 58 |
# File 'lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb', line 56 def token_secret @token_secret end |
#username ⇒ String
Returns The OAuth authentication code.
40 41 42 |
# File 'lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb', line 40 def username @username end |
Instance Method Details
#as_json(options = {}) ⇒ object
Returns This object as a JSON key-value structure.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb', line 60 def as_json(={}) { 'authCode' => @auth_code, 'username' => @username, 'password' => @password, 'realmId' => @realm_id, 'tokenId' => @token_id, 'tokenSecret' => @token_secret, } end |
#to_json(*options) ⇒ String
Returns This object converted to a JSON string.
73 74 75 |
# File 'lib/lockstep_sdk/models/app_enrollment_reconnect_info.rb', line 73 def to_json(*) "[#{as_json(*options).to_json(*options)}]" end |