Class: LockstepSdk::ApplicationModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/application_model.rb

Overview

An Application represents a feature available to customers within the Lockstep Platform. You can create Applications by working with your Lockstep business development manager and publish them on the platform so that customers can browse and find your Application on the Lockstep Platform Marketplace. When a customer adds an Application to their account, they obtain an AppEnrollment which represents that customer’s instance of this Application. The customer-specific AppEnrollment contains a customer’s configuration data for the Application, which is not customer-specific.

See [Applications and Enrollments](developer.lockstep.io/docs/applications-and-enrollments) for more information. –swaggerCategory:Platform

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ ApplicationModel

Initialize the ApplicationModel using the provided prototype



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/lockstep_sdk/models/application_model.rb', line 33

def initialize(params = {})
    @app_id = params.dig(:app_id)
    @name = params.dig(:name)
    @description = params.dig(:description)
    @app_type = params.dig(:app_type)
    @owner_id = params.dig(:owner_id)
    @project_url = params.dig(:project_url)
    @icon_url = params.dig(:icon_url)
    @price_terms = params.dig(:price_terms)
    @created_user_id = params.dig(:created_user_id)
    @modified_user_id = params.dig(:modified_user_id)
    @created = params.dig(:created)
    @modified = params.dig(:modified)
    @is_active = params.dig(:is_active)
    @wiki_url = params.dig(:wiki_url)
    @group_key = params.dig(:group_key)
    @notes = params.dig(:notes)
    @attachments = params.dig(:attachments)
    @custom_field_definitions = params.dig(:custom_field_definitions)
    @custom_field_values = params.dig(:custom_field_values)
end

Instance Attribute Details

#app_idUuid

Returns A unique code identifying this application.

Returns:

  • (Uuid)

    A unique code identifying this application



57
58
59
# File 'lib/lockstep_sdk/models/application_model.rb', line 57

def app_id
  @app_id
end

#app_typeString

Returns Tag for what type of app this is.

Returns:

  • (String)

    Tag for what type of app this is



69
70
71
# File 'lib/lockstep_sdk/models/application_model.rb', line 69

def app_type
  @app_type
end

#attachmentsAttachmentModel

Returns A collection of attachments linked to this record. To retrieve this collection, specify Attachments in the include parameter when retrieving data. To create an attachment, use the [Upload Attachment](developer.lockstep.io/reference/post_api-v1-attachments) endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



121
122
123
# File 'lib/lockstep_sdk/models/application_model.rb', line 121

def attachments
  @attachments
end

#createdDate-time

Returns The date this application was created.

Returns:

  • (Date-time)

    The date this application was created



97
98
99
# File 'lib/lockstep_sdk/models/application_model.rb', line 97

def created
  @created
end

#created_user_idUuid

Returns The ID of the user who created this application.

Returns:

  • (Uuid)

    The ID of the user who created this application



89
90
91
# File 'lib/lockstep_sdk/models/application_model.rb', line 89

def created_user_id
  @created_user_id
end

#custom_field_definitionsCustomFieldDefinitionModel

Returns A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldDefinitions in the include parameter when retrieving data. To create a custom field, use the [Create Custom Field](developer.lockstep.io/reference/post_api-v1-customfieldvalues) endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



125
126
127
# File 'lib/lockstep_sdk/models/application_model.rb', line 125

def custom_field_definitions
  @custom_field_definitions
end

#custom_field_valuesCustomFieldValueModel

Returns A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldValues in the include parameter when retrieving data. To create a custom field, use the [Create Custom Field](developer.lockstep.io/reference/post_api-v1-customfieldvalues) endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



129
130
131
# File 'lib/lockstep_sdk/models/application_model.rb', line 129

def custom_field_values
  @custom_field_values
end

#descriptionString

Returns Brief summary of this application shown as a subtitle.

Returns:

  • (String)

    Brief summary of this application shown as a subtitle



65
66
67
# File 'lib/lockstep_sdk/models/application_model.rb', line 65

def description
  @description
end

#group_keyUuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).

Returns:

  • (Uuid)

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).



113
114
115
# File 'lib/lockstep_sdk/models/application_model.rb', line 113

def group_key
  @group_key
end

#icon_urlUri

Returns The URL for the icon for this application.

Returns:

  • (Uri)

    The URL for the icon for this application



81
82
83
# File 'lib/lockstep_sdk/models/application_model.rb', line 81

def icon_url
  @icon_url
end

#is_activeBoolean

Returns Flag indicating if the application is active.

Returns:

  • (Boolean)

    Flag indicating if the application is active.



105
106
107
# File 'lib/lockstep_sdk/models/application_model.rb', line 105

def is_active
  @is_active
end

#modifiedDate-time

Returns The date this application was last modified.

Returns:

  • (Date-time)

    The date this application was last modified



101
102
103
# File 'lib/lockstep_sdk/models/application_model.rb', line 101

def modified
  @modified
end

#modified_user_idUuid

Returns The ID of the user who last modified this application.

Returns:

  • (Uuid)

    The ID of the user who last modified this application



93
94
95
# File 'lib/lockstep_sdk/models/application_model.rb', line 93

def modified_user_id
  @modified_user_id
end

#nameString

Returns The name of this application.

Returns:

  • (String)

    The name of this application



61
62
63
# File 'lib/lockstep_sdk/models/application_model.rb', line 61

def name
  @name
end

#notesNoteModel

Returns A collection of notes linked to this record. To retrieve this collection, specify Notes in the include parameter when retrieving data. To create a note, use the [Create Note](developer.lockstep.io/reference/post_api-v1-notes) endpoint with the TableKey to Application and the ObjectKey set to the ApplicationId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



117
118
119
# File 'lib/lockstep_sdk/models/application_model.rb', line 117

def notes
  @notes
end

#owner_idUuid

Returns The ID of the owner.

Returns:

  • (Uuid)

    The ID of the owner



73
74
75
# File 'lib/lockstep_sdk/models/application_model.rb', line 73

def owner_id
  @owner_id
end

#price_termsString

Returns The description of the price for this application.

Returns:

  • (String)

    The description of the price for this application



85
86
87
# File 'lib/lockstep_sdk/models/application_model.rb', line 85

def price_terms
  @price_terms
end

#project_urlUri

Returns The URL to visit for more information about this application.

Returns:

  • (Uri)

    The URL to visit for more information about this application



77
78
79
# File 'lib/lockstep_sdk/models/application_model.rb', line 77

def project_url
  @project_url
end

#wiki_urlUri

Returns URL to the Wiki for the Application.

Returns:

  • (Uri)

    URL to the Wiki for the Application



109
110
111
# File 'lib/lockstep_sdk/models/application_model.rb', line 109

def wiki_url
  @wiki_url
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object)

    This object as a JSON key-value structure



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/lockstep_sdk/models/application_model.rb', line 133

def as_json(options={})
    {
        'appId' => @app_id,
        'name' => @name,
        'description' => @description,
        'appType' => @app_type,
        'ownerId' => @owner_id,
        'projectUrl' => @project_url,
        'iconUrl' => @icon_url,
        'priceTerms' => @price_terms,
        'createdUserId' => @created_user_id,
        'modifiedUserId' => @modified_user_id,
        'created' => @created,
        'modified' => @modified,
        'isActive' => @is_active,
        'wikiURL' => @wiki_url,
        'groupKey' => @group_key,
        'notes' => @notes,
        'attachments' => @attachments,
        'customFieldDefinitions' => @custom_field_definitions,
        'customFieldValues' => @custom_field_values,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String)

    This object converted to a JSON string



159
160
161
# File 'lib/lockstep_sdk/models/application_model.rb', line 159

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end