Class: LockstepSdk::AttachmentHeaderInfoModel
- Inherits:
-
Object
- Object
- LockstepSdk::AttachmentHeaderInfoModel
- Defined in:
- lib/lockstep_sdk/models/attachment_header_info_model.rb
Overview
Aggregated Attachment status information.
Instance Attribute Summary collapse
-
#company_id ⇒ Uuid
The CompanyId associated with the attachment status report.
-
#group_key ⇒ Uuid
The GroupKey uniquely identifies a single Lockstep Platform account.
-
#total_active ⇒ Int32
The total number of active attachments associated with the provided GroupKey and CompanyId.
-
#total_archived ⇒ Int32
The total number of archived attachments associated with the provided GroupKey and CompanyId.
-
#total_attachments ⇒ Int32
The total number of attachments associated with the provided GroupKey and CompanyId.
Instance Method Summary collapse
-
#as_json(options = {}) ⇒ object
This object as a JSON key-value structure.
-
#initialize(params = {}) ⇒ AttachmentHeaderInfoModel
constructor
Initialize the AttachmentHeaderInfoModel using the provided prototype.
-
#to_json(*options) ⇒ String
This object converted to a JSON string.
Constructor Details
#initialize(params = {}) ⇒ AttachmentHeaderInfoModel
Initialize the AttachmentHeaderInfoModel using the provided prototype
25 26 27 28 29 30 31 |
# File 'lib/lockstep_sdk/models/attachment_header_info_model.rb', line 25 def initialize(params = {}) @group_key = params.dig(:group_key) @company_id = params.dig(:company_id) @total_attachments = params.dig(:total_attachments) @total_archived = params.dig(:total_archived) @total_active = params.dig(:total_active) end |
Instance Attribute Details
#company_id ⇒ Uuid
Returns The CompanyId associated with the attachment status report. Providing a null value will return an attachment summary for all attachments associated to the provided GroupKey.
39 40 41 |
# File 'lib/lockstep_sdk/models/attachment_header_info_model.rb', line 39 def company_id @company_id end |
#group_key ⇒ Uuid
Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.
35 36 37 |
# File 'lib/lockstep_sdk/models/attachment_header_info_model.rb', line 35 def group_key @group_key end |
#total_active ⇒ Int32
Returns The total number of active attachments associated with the provided GroupKey and CompanyId.
51 52 53 |
# File 'lib/lockstep_sdk/models/attachment_header_info_model.rb', line 51 def total_active @total_active end |
#total_archived ⇒ Int32
Returns The total number of archived attachments associated with the provided GroupKey and CompanyId.
47 48 49 |
# File 'lib/lockstep_sdk/models/attachment_header_info_model.rb', line 47 def total_archived @total_archived end |
#total_attachments ⇒ Int32
Returns The total number of attachments associated with the provided GroupKey and CompanyId.
43 44 45 |
# File 'lib/lockstep_sdk/models/attachment_header_info_model.rb', line 43 def @total_attachments end |
Instance Method Details
#as_json(options = {}) ⇒ object
Returns This object as a JSON key-value structure.
55 56 57 58 59 60 61 62 63 |
# File 'lib/lockstep_sdk/models/attachment_header_info_model.rb', line 55 def as_json(={}) { 'groupKey' => @group_key, 'companyId' => @company_id, 'totalAttachments' => @total_attachments, 'totalArchived' => @total_archived, 'totalActive' => @total_active, } end |
#to_json(*options) ⇒ String
Returns This object converted to a JSON string.
67 68 69 |
# File 'lib/lockstep_sdk/models/attachment_header_info_model.rb', line 67 def to_json(*) "[#{as_json(*).to_json(*)}]" end |