Class: LockstepSdk::CompanyModel

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/models/company_model.rb

Overview

A Company represents a customer, a vendor, or a company within the organization of the account holder. Companies can have parents and children, representing an organizational hierarchy of corporate entities. You can use Companies to track projects and financial data under this Company label.

See [Vendors, Customers, and Companies](developer.lockstep.io/docs/companies-customers-and-vendors) for more information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(params = {}) ⇒ CompanyModel

Initialize the CompanyModel using the provided prototype



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/lockstep_sdk/models/company_model.rb', line 29

def initialize(params = {})
    @company_id = params.dig(:company_id)
    @company_name = params.dig(:company_name)
    @erp_key = params.dig(:erp_key)
    @company_type = params.dig(:company_type)
    @company_status = params.dig(:company_status)
    @parent_company_id = params.dig(:parent_company_id)
    @enterprise_id = params.dig(:enterprise_id)
    @group_key = params.dig(:group_key)
    @is_active = params.dig(:is_active)
    @default_currency_code = params.dig(:default_currency_code)
    @company_logo_url = params.dig(:company_logo_url)
    @primary_contact_id = params.dig(:primary_contact_id)
    @address1 = params.dig(:address1)
    @address2 = params.dig(:address2)
    @address3 = params.dig(:address3)
    @city = params.dig(:city)
    @state_region = params.dig(:state_region)
    @postal_code = params.dig(:postal_code)
    @country = params.dig(:country)
    @time_zone = params.dig(:time_zone)
    @phone_number = params.dig(:phone_number)
    @fax_number = params.dig(:fax_number)
    @created = params.dig(:created)
    @created_user_id = params.dig(:created_user_id)
    @modified = params.dig(:modified)
    @modified_user_id = params.dig(:modified_user_id)
    @modified_user_name = params.dig(:modified_user_name)
    @tax_id = params.dig(:tax_id)
    @duns_number = params.dig(:duns_number)
    @ap_email_address = params.dig(:ap_email_address)
    @ar_email_address = params.dig(:ar_email_address)
    @preferred_delivery_method = params.dig(:preferred_delivery_method)
    @domain_name = params.dig(:domain_name)
    @company_classification_code_def_id = params.dig(:company_classification_code_def_id)
    @description = params.dig(:description)
    @website = params.dig(:website)
    @app_enrollment_id = params.dig(:app_enrollment_id)
    @notes = params.dig(:notes)
    @attachments = params.dig(:attachments)
    @contacts = params.dig(:contacts)
    @invoices = params.dig(:invoices)
    @custom_field_definitions = params.dig(:custom_field_definitions)
    @custom_field_values = params.dig(:custom_field_values)
    @company_classification_code_definition = params.dig(:company_classification_code_definition)
end

Instance Attribute Details

#address1String

Returns Address info.

Returns:

  • (String)

    Address info



126
127
128
# File 'lib/lockstep_sdk/models/company_model.rb', line 126

def address1
  @address1
end

#address2String

Returns Address info.

Returns:

  • (String)

    Address info



130
131
132
# File 'lib/lockstep_sdk/models/company_model.rb', line 130

def address2
  @address2
end

#address3String

Returns Address info.

Returns:

  • (String)

    Address info



134
135
136
# File 'lib/lockstep_sdk/models/company_model.rb', line 134

def address3
  @address3
end

#ap_email_addressEmail

Returns AP (Accounts Payable) Email Address.

Returns:

  • (Email)

    AP (Accounts Payable) Email Address



194
195
196
# File 'lib/lockstep_sdk/models/company_model.rb', line 194

def ap_email_address
  @ap_email_address
end

#app_enrollment_idUuid

Returns The AppEnrollmentId of the application that imported this record. For accounts with more than one financial system connected, this field identifies the originating financial system that produced this record. This value is null if this record was not loaded from an external ERP or financial system.

Returns:

  • (Uuid)

    The AppEnrollmentId of the application that imported this record. For accounts with more than one financial system connected, this field identifies the originating financial system that produced this record. This value is null if this record was not loaded from an external ERP or financial system.



222
223
224
# File 'lib/lockstep_sdk/models/company_model.rb', line 222

def app_enrollment_id
  @app_enrollment_id
end

#ar_email_addressEmail

Returns AR (Accounts Receivable) Email Address.

Returns:

  • (Email)

    AR (Accounts Receivable) Email Address



198
199
200
# File 'lib/lockstep_sdk/models/company_model.rb', line 198

def ar_email_address
  @ar_email_address
end

#attachmentsAttachmentModel

Returns A collection of attachments linked to this record. To retrieve this collection, specify Attachments in the include parameter when retrieving data. To create an attachment, use the [Upload Attachment](developer.lockstep.io/reference/post_api-v1-attachments) endpoint with the TableKey to Company and the ObjectKey set to the CompanyId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



230
231
232
# File 'lib/lockstep_sdk/models/company_model.rb', line 230

def attachments
  @attachments
end

#cityString

Returns Address info.

Returns:

  • (String)

    Address info



138
139
140
# File 'lib/lockstep_sdk/models/company_model.rb', line 138

def city
  @city
end

#company_classification_code_def_idUuid

Returns Identifier for classification of this company.

Returns:

  • (Uuid)

    Identifier for classification of this company.



210
211
212
# File 'lib/lockstep_sdk/models/company_model.rb', line 210

def company_classification_code_def_id
  @company_classification_code_def_id
end

#company_classification_code_definitionCodeDefinitionModel

Returns Classification code definition for this company. To retrieve this collection, specify Classification in the “Include” parameter for your query.

Returns:

  • (CodeDefinitionModel)

    Classification code definition for this company. To retrieve this collection, specify Classification in the “Include” parameter for your query.



250
251
252
# File 'lib/lockstep_sdk/models/company_model.rb', line 250

def company_classification_code_definition
  @company_classification_code_definition
end

#company_idUuid

Returns The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform. For the ID of this record in its originating financial system, see ErpKey.

Returns:

  • (Uuid)

    The unique ID of this record, automatically assigned by Lockstep when this record is added to the Lockstep platform. For the ID of this record in its originating financial system, see ErpKey.



78
79
80
# File 'lib/lockstep_sdk/models/company_model.rb', line 78

def company_id
  @company_id
end

#company_logo_urlString

Returns The URL of this company’s logo, if known.

Returns:

  • (String)

    The URL of this company’s logo, if known.



118
119
120
# File 'lib/lockstep_sdk/models/company_model.rb', line 118

def company_logo_url
  @company_logo_url
end

#company_nameString

Returns The short name of the company.

Returns:

  • (String)

    The short name of the company.



82
83
84
# File 'lib/lockstep_sdk/models/company_model.rb', line 82

def company_name
  @company_name
end

#company_statusString

Returns The status of the company. Companies can be either Active or Inactive. When matched to a Lockstep corporate profile, this value will change to reflect that this record will be kept in sync with that company’s identity.

Returns:

  • (String)

    The status of the company. Companies can be either Active or Inactive. When matched to a Lockstep corporate profile, this value will change to reflect that this record will be kept in sync with that company’s identity.



94
95
96
# File 'lib/lockstep_sdk/models/company_model.rb', line 94

def company_status
  @company_status
end

#company_typeString

Returns This field indicates the type of company. It can be one of a limited number of values: Company, Customer, Group, Vendor, or Third Party. A company that represents both a customer and a vendor is identified as a CustomerVendor. * Company - This record represents a company that is part of the organization of the account holder. * Customer - This record represents a business entity that purchases things from the account holder. * Group - Only one record of type GROUP exists in each account. Contains your account profile. * Vendor - This record represents a business entity that sells things to the account holder. * ‘Third Party` - This record represents a business entity that is neither a customer nor vendor. * CustomerVendor - Both a customer and a vendor.

Returns:

  • (String)

    This field indicates the type of company. It can be one of a limited number of values: Company, Customer, Group, Vendor, or Third Party. A company that represents both a customer and a vendor is identified as a CustomerVendor. * Company - This record represents a company that is part of the organization of the account holder. * Customer - This record represents a business entity that purchases things from the account holder. * Group - Only one record of type GROUP exists in each account. Contains your account profile. * Vendor - This record represents a business entity that sells things to the account holder. * ‘Third Party` - This record represents a business entity that is neither a customer nor vendor. * CustomerVendor - Both a customer and a vendor.



90
91
92
# File 'lib/lockstep_sdk/models/company_model.rb', line 90

def company_type
  @company_type
end

#contactsContactModel

Returns All contacts attached to this company. To retrieve this collection, specify Contacts in the “Include” parameter for your query.

Returns:

  • (ContactModel)

    All contacts attached to this company. To retrieve this collection, specify Contacts in the “Include” parameter for your query.



234
235
236
# File 'lib/lockstep_sdk/models/company_model.rb', line 234

def contacts
  @contacts
end

#countryString

Returns Address info.

Returns:

  • (String)

    Address info



150
151
152
# File 'lib/lockstep_sdk/models/company_model.rb', line 150

def country
  @country
end

#createdDate-time

Returns The date this company was created.

Returns:

  • (Date-time)

    The date this company was created



166
167
168
# File 'lib/lockstep_sdk/models/company_model.rb', line 166

def created
  @created
end

#created_user_idUuid

Returns The ID of the user who created this company.

Returns:

  • (Uuid)

    The ID of the user who created this company



170
171
172
# File 'lib/lockstep_sdk/models/company_model.rb', line 170

def created_user_id
  @created_user_id
end

#custom_field_definitionsCustomFieldDefinitionModel

Returns A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldDefinitions in the include parameter when retrieving data. To create a custom field, use the [Create Custom Field](developer.lockstep.io/reference/post_api-v1-customfieldvalues) endpoint with the TableKey to Company and the ObjectKey set to the CompanyId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



242
243
244
# File 'lib/lockstep_sdk/models/company_model.rb', line 242

def custom_field_definitions
  @custom_field_definitions
end

#custom_field_valuesCustomFieldValueModel

Returns A collection of custom fields linked to this record. To retrieve this collection, specify CustomFieldValues in the include parameter when retrieving data. To create a custom field, use the [Create Custom Field](developer.lockstep.io/reference/post_api-v1-customfieldvalues) endpoint with the TableKey to Company and the ObjectKey set to the CompanyId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



246
247
248
# File 'lib/lockstep_sdk/models/company_model.rb', line 246

def custom_field_values
  @custom_field_values
end

#default_currency_codeString

Returns The default currency code used by this business entity. This value can be overridden for invoices in a different currency code. For a list of defined currency codes, see [Query Currencies](developer.lockstep.io/reference/get_api-v1-definitions-currencies).

Returns:



114
115
116
# File 'lib/lockstep_sdk/models/company_model.rb', line 114

def default_currency_code
  @default_currency_code
end

#descriptionString

Returns Description of the company.

Returns:

  • (String)

    Description of the company.



214
215
216
# File 'lib/lockstep_sdk/models/company_model.rb', line 214

def description
  @description
end

#domain_nameString

Returns For companies that use a custom domain name for their email system, this is the domain name used by this company. If this value is known, new emails that come in from this domain will be connected to this company.

Returns:

  • (String)

    For companies that use a custom domain name for their email system, this is the domain name used by this company. If this value is known, new emails that come in from this domain will be connected to this company.



206
207
208
# File 'lib/lockstep_sdk/models/company_model.rb', line 206

def domain_name
  @domain_name
end

#duns_numberString

Returns Dun & Bradstreet Number.

Returns:

  • (String)

    Dun & Bradstreet Number



190
191
192
# File 'lib/lockstep_sdk/models/company_model.rb', line 190

def duns_number
  @duns_number
end

#enterprise_idUuid

Returns For convenience, this field indicates the top-level parent company. This can be used to jump directly to the top parent in complex organizational hierarchies.

Returns:

  • (Uuid)

    For convenience, this field indicates the top-level parent company. This can be used to jump directly to the top parent in complex organizational hierarchies.



102
103
104
# File 'lib/lockstep_sdk/models/company_model.rb', line 102

def enterprise_id
  @enterprise_id
end

#erp_keyString

Returns The unique ID of this record as it was known in its originating financial system. If this company record was imported from a financial system, it will have the value ErpKey set to the original primary key number of the record as it was known in the originating financial system. If this record was not imported, this value will be null. For more information, see [Identity Columns](developer.lockstep.io/docs/identity-columns).

Returns:

  • (String)

    The unique ID of this record as it was known in its originating financial system. If this company record was imported from a financial system, it will have the value ErpKey set to the original primary key number of the record as it was known in the originating financial system. If this record was not imported, this value will be null. For more information, see [Identity Columns](developer.lockstep.io/docs/identity-columns).



86
87
88
# File 'lib/lockstep_sdk/models/company_model.rb', line 86

def erp_key
  @erp_key
end

#fax_numberString

Returns Fax number.

Returns:

  • (String)

    Fax number



162
163
164
# File 'lib/lockstep_sdk/models/company_model.rb', line 162

def fax_number
  @fax_number
end

#group_keyUuid

Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).

Returns:

  • (Uuid)

    The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).



106
107
108
# File 'lib/lockstep_sdk/models/company_model.rb', line 106

def group_key
  @group_key
end

#invoicesObject

Returns All invoices attached to this company. To retrieve this collection, specify Invoices in the “Include” parameter for your query. For more information on Invoices, see [InvoiceModel](developer.lockstep.io/reference/get_api-v1-invoices-id).

Returns:



238
239
240
# File 'lib/lockstep_sdk/models/company_model.rb', line 238

def invoices
  @invoices
end

#is_activeBoolean

Returns This flag indicates whether the company is currently active. An inactive company should be hidden from the user interface but will still be available for querying.

Returns:

  • (Boolean)

    This flag indicates whether the company is currently active. An inactive company should be hidden from the user interface but will still be available for querying.



110
111
112
# File 'lib/lockstep_sdk/models/company_model.rb', line 110

def is_active
  @is_active
end

#modifiedDate-time

Returns The date this company was last modified.

Returns:

  • (Date-time)

    The date this company was last modified



174
175
176
# File 'lib/lockstep_sdk/models/company_model.rb', line 174

def modified
  @modified
end

#modified_user_idUuid

Returns The ID of the user who last modified this company.

Returns:

  • (Uuid)

    The ID of the user who last modified this company



178
179
180
# File 'lib/lockstep_sdk/models/company_model.rb', line 178

def modified_user_id
  @modified_user_id
end

#modified_user_nameString

Returns The name of the user who last modified this company.

Returns:

  • (String)

    The name of the user who last modified this company



182
183
184
# File 'lib/lockstep_sdk/models/company_model.rb', line 182

def modified_user_name
  @modified_user_name
end

#notesNoteModel

Returns A collection of notes linked to this record. To retrieve this collection, specify Notes in the include parameter when retrieving data. To create a note, use the [Create Note](developer.lockstep.io/reference/post_api-v1-notes) endpoint with the TableKey to Company and the ObjectKey set to the CompanyId for this record. For more information on extensibility, see [linking extensible metadata to objects](developer.lockstep.io/docs/custom-fields#linking-metadata-to-an-object).

Returns:



226
227
228
# File 'lib/lockstep_sdk/models/company_model.rb', line 226

def notes
  @notes
end

#parent_company_idUuid

Returns If this business entity is part of an organization, this value is non-null and it is set to the CompanyId value of the parent company of this business entity. If this value is null, this business entity is a standalone.

Returns:

  • (Uuid)

    If this business entity is part of an organization, this value is non-null and it is set to the CompanyId value of the parent company of this business entity. If this value is null, this business entity is a standalone.



98
99
100
# File 'lib/lockstep_sdk/models/company_model.rb', line 98

def parent_company_id
  @parent_company_id
end

#phone_numberString

Returns Phone number.

Returns:

  • (String)

    Phone number



158
159
160
# File 'lib/lockstep_sdk/models/company_model.rb', line 158

def phone_number
  @phone_number
end

#postal_codeString

Returns Address info.

Returns:

  • (String)

    Address info



146
147
148
# File 'lib/lockstep_sdk/models/company_model.rb', line 146

def postal_code
  @postal_code
end

#preferred_delivery_methodString

Returns Indicates the preferred invoice delivery method. Examples include Print, Email, Fax.

Returns:

  • (String)

    Indicates the preferred invoice delivery method. Examples include Print, Email, Fax



202
203
204
# File 'lib/lockstep_sdk/models/company_model.rb', line 202

def preferred_delivery_method
  @preferred_delivery_method
end

#primary_contact_idUuid

Returns The Lockstep ContactId of the primary contact for this company.

Returns:

  • (Uuid)

    The Lockstep ContactId of the primary contact for this company.



122
123
124
# File 'lib/lockstep_sdk/models/company_model.rb', line 122

def primary_contact_id
  @primary_contact_id
end

#state_regionString

Returns Address info.

Returns:

  • (String)

    Address info



142
143
144
# File 'lib/lockstep_sdk/models/company_model.rb', line 142

def state_region
  @state_region
end

#tax_idString

Returns Federal Tax ID.

Returns:

  • (String)

    Federal Tax ID



186
187
188
# File 'lib/lockstep_sdk/models/company_model.rb', line 186

def tax_id
  @tax_id
end

#time_zoneString

Returns Time zone.

Returns:

  • (String)

    Time zone



154
155
156
# File 'lib/lockstep_sdk/models/company_model.rb', line 154

def time_zone
  @time_zone
end

#websiteString

Returns Website URL for this company.

Returns:

  • (String)

    Website URL for this company.



218
219
220
# File 'lib/lockstep_sdk/models/company_model.rb', line 218

def website
  @website
end

Instance Method Details

#as_json(options = {}) ⇒ object

Returns This object as a JSON key-value structure.

Returns:

  • (object)

    This object as a JSON key-value structure



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/lockstep_sdk/models/company_model.rb', line 254

def as_json(options={})
    {
        'companyId' => @company_id,
        'companyName' => @company_name,
        'erpKey' => @erp_key,
        'companyType' => @company_type,
        'companyStatus' => @company_status,
        'parentCompanyId' => @parent_company_id,
        'enterpriseId' => @enterprise_id,
        'groupKey' => @group_key,
        'isActive' => @is_active,
        'defaultCurrencyCode' => @default_currency_code,
        'companyLogoUrl' => @company_logo_url,
        'primaryContactId' => @primary_contact_id,
        'address1' => @address1,
        'address2' => @address2,
        'address3' => @address3,
        'city' => @city,
        'stateRegion' => @state_region,
        'postalCode' => @postal_code,
        'country' => @country,
        'timeZone' => @time_zone,
        'phoneNumber' => @phone_number,
        'faxNumber' => @fax_number,
        'created' => @created,
        'createdUserId' => @created_user_id,
        'modified' => @modified,
        'modifiedUserId' => @modified_user_id,
        'modifiedUserName' => @modified_user_name,
        'taxId' => @tax_id,
        'dunsNumber' => @duns_number,
        'apEmailAddress' => @ap_email_address,
        'arEmailAddress' => @ar_email_address,
        'preferredDeliveryMethod' => @preferred_delivery_method,
        'domainName' => @domain_name,
        'companyClassificationCodeDefId' => @company_classification_code_def_id,
        'description' => @description,
        'website' => @website,
        'appEnrollmentId' => @app_enrollment_id,
        'notes' => @notes,
        'attachments' => @attachments,
        'contacts' => @contacts,
        'invoices' => @invoices,
        'customFieldDefinitions' => @custom_field_definitions,
        'customFieldValues' => @custom_field_values,
        'companyClassificationCodeDefinition' => @company_classification_code_definition,
    }
end

#to_json(*options) ⇒ String

Returns This object converted to a JSON string.

Returns:

  • (String)

    This object converted to a JSON string



305
306
307
# File 'lib/lockstep_sdk/models/company_model.rb', line 305

def to_json(*options)
    "[#{as_json(*options).to_json(*options)}]"
end