Class: LockstepSdk::DpoSummaryGroupTotalModel
- Inherits:
-
Object
- Object
- LockstepSdk::DpoSummaryGroupTotalModel
- Defined in:
- lib/lockstep_sdk/models/dpo_summary_group_total_model.rb
Overview
Represents the group totals for the values found in the daily payable outstanding summary
Instance Attribute Summary collapse
-
#amount_outstanding ⇒ Double
The total amount outstanding at the group's base currency.
-
#base_currency_code ⇒ String
The group's base currency code.
-
#bills ⇒ Int32
The total number of bills outstanding.
-
#dpo ⇒ Double
The total dpo for the group key.
-
#group_key ⇒ Uuid
The GroupKey uniquely identifies a single Lockstep Platform account.
-
#vendors ⇒ Int32
The total number of vendors with outstanding bills.
Instance Method Summary collapse
-
#as_json(options = {}) ⇒ object
This object as a JSON key-value structure.
-
#initialize(params = {}) ⇒ DpoSummaryGroupTotalModel
constructor
Initialize the DpoSummaryGroupTotalModel using the provided prototype.
-
#to_json(*options) ⇒ String
This object converted to a JSON string.
Constructor Details
#initialize(params = {}) ⇒ DpoSummaryGroupTotalModel
Initialize the DpoSummaryGroupTotalModel using the provided prototype
25 26 27 28 29 30 31 32 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 25 def initialize(params = {}) @group_key = params.dig(:group_key) @vendors = params.dig(:vendors) @bills = params.dig(:bills) @base_currency_code = params.dig(:base_currency_code) @amount_outstanding = params.dig(:amount_outstanding) @dpo = params.dig(:dpo) end |
Instance Attribute Details
#amount_outstanding ⇒ Double
Returns The total amount outstanding at the group's base currency.
52 53 54 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 52 def amount_outstanding @amount_outstanding end |
#base_currency_code ⇒ String
Returns The group's base currency code.
48 49 50 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 48 def base_currency_code @base_currency_code end |
#bills ⇒ Int32
Returns The total number of bills outstanding.
44 45 46 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 44 def bills @bills end |
#dpo ⇒ Double
Returns The total dpo for the group key.
56 57 58 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 56 def dpo @dpo end |
#group_key ⇒ Uuid
Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.
36 37 38 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 36 def group_key @group_key end |
#vendors ⇒ Int32
Returns The total number of vendors with outstanding bills.
40 41 42 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 40 def vendors @vendors end |
Instance Method Details
#as_json(options = {}) ⇒ object
Returns This object as a JSON key-value structure.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 60 def as_json(={}) { 'groupKey' => @group_key, 'vendors' => @vendors, 'bills' => @bills, 'baseCurrencyCode' => @base_currency_code, 'amountOutstanding' => @amount_outstanding, 'dpo' => @dpo, } end |
#to_json(*options) ⇒ String
Returns This object converted to a JSON string.
73 74 75 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 73 def to_json(*) "[#{as_json(*).to_json(*)}]" end |