Class: LockstepSdk::DpoSummaryGroupTotalModel
- Inherits:
-
Object
- Object
- LockstepSdk::DpoSummaryGroupTotalModel
- Defined in:
- lib/lockstep_sdk/models/dpo_summary_group_total_model.rb
Overview
Represents the group totals for the values found in the daily payable outstanding summary
Instance Attribute Summary collapse
-
#amount_outstanding ⇒ Double
The total amount outstanding.
-
#bills ⇒ Int32
The total number of bills outstanding.
-
#dpo ⇒ Double
The total dpo for the group key.
-
#group_key ⇒ Uuid
The GroupKey uniquely identifies a single Lockstep Platform account.
-
#vendors ⇒ Int32
The total number of vendors with outstanding bills.
Instance Method Summary collapse
-
#as_json(options = {}) ⇒ object
This object as a JSON key-value structure.
-
#initialize(params = {}) ⇒ DpoSummaryGroupTotalModel
constructor
Initialize the DpoSummaryGroupTotalModel using the provided prototype.
-
#to_json(*options) ⇒ String
This object converted to a JSON string.
Constructor Details
#initialize(params = {}) ⇒ DpoSummaryGroupTotalModel
Initialize the DpoSummaryGroupTotalModel using the provided prototype
25 26 27 28 29 30 31 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 25 def initialize(params = {}) @group_key = params.dig(:group_key) @vendors = params.dig(:vendors) @bills = params.dig(:bills) @amount_outstanding = params.dig(:amount_outstanding) @dpo = params.dig(:dpo) end |
Instance Attribute Details
#amount_outstanding ⇒ Double
Returns The total amount outstanding.
47 48 49 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 47 def amount_outstanding @amount_outstanding end |
#bills ⇒ Int32
Returns The total number of bills outstanding.
43 44 45 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 43 def bills @bills end |
#dpo ⇒ Double
Returns The total dpo for the group key.
51 52 53 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 51 def dpo @dpo end |
#group_key ⇒ Uuid
Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see [Accounts and GroupKeys](developer.lockstep.io/docs/accounts-and-groupkeys).
35 36 37 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 35 def group_key @group_key end |
#vendors ⇒ Int32
Returns The total number of vendors with outstanding bills.
39 40 41 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 39 def vendors @vendors end |
Instance Method Details
#as_json(options = {}) ⇒ object
Returns This object as a JSON key-value structure.
55 56 57 58 59 60 61 62 63 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 55 def as_json(={}) { 'groupKey' => @group_key, 'vendors' => @vendors, 'bills' => @bills, 'amountOutstanding' => @amount_outstanding, 'dpo' => @dpo, } end |
#to_json(*options) ⇒ String
Returns This object converted to a JSON string.
67 68 69 |
# File 'lib/lockstep_sdk/models/dpo_summary_group_total_model.rb', line 67 def to_json(*) "[#{as_json(*options).to_json(*options)}]" end |