Class: LockstepSdk::GroupAccountModel
- Inherits:
-
Object
- Object
- LockstepSdk::GroupAccountModel
- Defined in:
- lib/lockstep_sdk/models/group_account_model.rb
Overview
Represents an account for an entire group
Instance Attribute Summary collapse
-
#base_currency_code ⇒ String
Base Currency of the group.
-
#country_code ⇒ String
The 2-letter ISO country code for the group.
-
#created ⇒ Date-time
The date this group account was created.
-
#created_user_id ⇒ Uuid
The ID of the user who created this group account.
-
#group_company_id ⇒ Uuid
The CompanyId of the Company the group is associated with.
-
#group_key ⇒ Uuid
The GroupKey uniquely identifies a single Lockstep Platform account.
-
#group_name ⇒ String
The name of the group.
-
#is_active ⇒ Boolean
The active status of the group.
-
#modified ⇒ Date-time
The date this group account was last modified.
-
#modified_user_id ⇒ Uuid
The ID of the user who last modified this group account.
-
#onboarding_scheduled ⇒ Boolean
The onboarding session status of the group.
-
#primary_user_id ⇒ Uuid
The primary user for the group.
Instance Method Summary collapse
-
#as_json(options = {}) ⇒ object
This object as a JSON key-value structure.
-
#initialize(params = {}) ⇒ GroupAccountModel
constructor
Initialize the GroupAccountModel using the provided prototype.
-
#to_json(*options) ⇒ String
This object converted to a JSON string.
Constructor Details
#initialize(params = {}) ⇒ GroupAccountModel
Initialize the GroupAccountModel using the provided prototype
25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 25 def initialize(params = {}) @group_key = params.dig(:group_key) @group_name = params.dig(:group_name) @primary_user_id = params.dig(:primary_user_id) @group_company_id = params.dig(:group_company_id) @base_currency_code = params.dig(:base_currency_code) @is_active = params.dig(:is_active) @onboarding_scheduled = params.dig(:onboarding_scheduled) @created = params.dig(:created) @created_user_id = params.dig(:created_user_id) @modified = params.dig(:modified) @modified_user_id = params.dig(:modified_user_id) @country_code = params.dig(:country_code) end |
Instance Attribute Details
#base_currency_code ⇒ String
Returns Base Currency of the group.
58 59 60 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 58 def base_currency_code @base_currency_code end |
#country_code ⇒ String
Returns The 2-letter ISO country code for the group.
86 87 88 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 86 def country_code @country_code end |
#created ⇒ Date-time
Returns The date this group account was created.
70 71 72 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 70 def created @created end |
#created_user_id ⇒ Uuid
Returns The ID of the user who created this group account.
74 75 76 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 74 def created_user_id @created_user_id end |
#group_company_id ⇒ Uuid
Returns The CompanyId of the Company the group is associated with.
54 55 56 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 54 def group_company_id @group_company_id end |
#group_key ⇒ Uuid
Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.
42 43 44 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 42 def group_key @group_key end |
#group_name ⇒ String
Returns The name of the group.
46 47 48 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 46 def group_name @group_name end |
#is_active ⇒ Boolean
Returns The active status of the group.
62 63 64 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 62 def is_active @is_active end |
#modified ⇒ Date-time
Returns The date this group account was last modified.
78 79 80 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 78 def modified @modified end |
#modified_user_id ⇒ Uuid
Returns The ID of the user who last modified this group account.
82 83 84 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 82 def modified_user_id @modified_user_id end |
#onboarding_scheduled ⇒ Boolean
Returns The onboarding session status of the group.
66 67 68 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 66 def onboarding_scheduled @onboarding_scheduled end |
#primary_user_id ⇒ Uuid
Returns The primary user for the group.
50 51 52 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 50 def primary_user_id @primary_user_id end |
Instance Method Details
#as_json(options = {}) ⇒ object
Returns This object as a JSON key-value structure.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 90 def as_json(={}) { 'groupKey' => @group_key, 'groupName' => @group_name, 'primaryUserId' => @primary_user_id, 'groupCompanyId' => @group_company_id, 'baseCurrencyCode' => @base_currency_code, 'isActive' => @is_active, 'onboardingScheduled' => @onboarding_scheduled, 'created' => @created, 'createdUserId' => @created_user_id, 'modified' => @modified, 'modifiedUserId' => @modified_user_id, 'countryCode' => @country_code, } end |
#to_json(*options) ⇒ String
Returns This object converted to a JSON string.
109 110 111 |
# File 'lib/lockstep_sdk/models/group_account_model.rb', line 109 def to_json(*) "[#{as_json(*).to_json(*)}]" end |