Method: LockstepSdk::InvoiceSyncModel#terms_code
- Defined in:
- lib/lockstep_sdk/models/invoice_sync_model.rb
#terms_code ⇒ String
Returns A code identifying the terms given to the purchaser. This field is imported directly from the originating financial system and does not follow a specified format.
138 139 140 |
# File 'lib/lockstep_sdk/models/invoice_sync_model.rb', line 138 def terms_code @terms_code end |