Class: LockstepSdk::PaymentModelErpWriteResult
- Inherits:
-
Object
- Object
- LockstepSdk::PaymentModelErpWriteResult
- Defined in:
- lib/lockstep_sdk/models/payment_model_erp_write_result.rb
Overview
Contains results of a write back request
Instance Attribute Summary collapse
-
#app_enrollment_id ⇒ Uuid
The id of the connected AppEnrollmentModel.
-
#erp_key ⇒ String
The ErpKey for the object written to the Erp if created.
-
#group_key ⇒ Uuid
The GroupKey uniquely identifies a single Lockstep Platform account.
-
#message ⇒ String
An optional message to return with the result.
-
#results ⇒ PaymentModel
Results from the ERP write operation.
-
#sync_request_id ⇒ Uuid
The id of the SyncRequestModel the requests were added to.
Instance Method Summary collapse
-
#as_json(options = {}) ⇒ object
This object as a JSON key-value structure.
-
#initialize(params = {}) ⇒ PaymentModelErpWriteResult
constructor
Initialize the PaymentModelErpWriteResult using the provided prototype.
-
#to_json(*options) ⇒ String
This object converted to a JSON string.
Constructor Details
#initialize(params = {}) ⇒ PaymentModelErpWriteResult
Initialize the PaymentModelErpWriteResult using the provided prototype
25 26 27 28 29 30 31 32 |
# File 'lib/lockstep_sdk/models/payment_model_erp_write_result.rb', line 25 def initialize(params = {}) @app_enrollment_id = params.dig(:app_enrollment_id) @erp_key = params.dig(:erp_key) @group_key = params.dig(:group_key) @message = params.dig(:message) @sync_request_id = params.dig(:sync_request_id) @results = params.dig(:results) end |
Instance Attribute Details
#app_enrollment_id ⇒ Uuid
Returns The id of the connected AppEnrollmentModel.
36 37 38 |
# File 'lib/lockstep_sdk/models/payment_model_erp_write_result.rb', line 36 def app_enrollment_id @app_enrollment_id end |
#erp_key ⇒ String
Returns The ErpKey for the object written to the Erp if created.
40 41 42 |
# File 'lib/lockstep_sdk/models/payment_model_erp_write_result.rb', line 40 def erp_key @erp_key end |
#group_key ⇒ Uuid
Returns The GroupKey uniquely identifies a single Lockstep Platform account. All records for this account will share the same GroupKey value. GroupKey values cannot be changed once created. For more information, see Accounts and GroupKeys.
44 45 46 |
# File 'lib/lockstep_sdk/models/payment_model_erp_write_result.rb', line 44 def group_key @group_key end |
#message ⇒ String
Returns An optional message to return with the result.
48 49 50 |
# File 'lib/lockstep_sdk/models/payment_model_erp_write_result.rb', line 48 def @message end |
#results ⇒ PaymentModel
Returns Results from the ERP write operation.
56 57 58 |
# File 'lib/lockstep_sdk/models/payment_model_erp_write_result.rb', line 56 def results @results end |
#sync_request_id ⇒ Uuid
Returns The id of the SyncRequestModel the requests were added to.
52 53 54 |
# File 'lib/lockstep_sdk/models/payment_model_erp_write_result.rb', line 52 def sync_request_id @sync_request_id end |
Instance Method Details
#as_json(options = {}) ⇒ object
Returns This object as a JSON key-value structure.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/lockstep_sdk/models/payment_model_erp_write_result.rb', line 60 def as_json(={}) { 'appEnrollmentId' => @app_enrollment_id, 'erpKey' => @erp_key, 'groupKey' => @group_key, 'message' => @message, 'syncRequestId' => @sync_request_id, 'results' => @results, } end |
#to_json(*options) ⇒ String
Returns This object converted to a JSON string.
73 74 75 |
# File 'lib/lockstep_sdk/models/payment_model_erp_write_result.rb', line 73 def to_json(*) "[#{as_json(*).to_json(*)}]" end |