Class: LockstepSdk::ProvisioningModel
- Inherits:
-
Object
- Object
- LockstepSdk::ProvisioningModel
- Defined in:
- lib/lockstep_sdk/models/provisioning_model.rb
Overview
Represents the data sent during the onboarding flow
Instance Attribute Summary collapse
-
#erp ⇒ ErpInfoModel
The information necessary to enroll the user in their ERP.
-
#full_name ⇒ String
The full name of the new user.
Instance Method Summary collapse
-
#as_json(options = {}) ⇒ object
This object as a JSON key-value structure.
-
#initialize(params = {}) ⇒ ProvisioningModel
constructor
Initialize the ProvisioningModel using the provided prototype.
-
#to_json(*options) ⇒ String
This object converted to a JSON string.
Constructor Details
#initialize(params = {}) ⇒ ProvisioningModel
Initialize the ProvisioningModel using the provided prototype
25 26 27 28 |
# File 'lib/lockstep_sdk/models/provisioning_model.rb', line 25 def initialize(params = {}) @full_name = params.dig(:full_name) @erp = params.dig(:erp) end |
Instance Attribute Details
#erp ⇒ ErpInfoModel
Returns The information necessary to enroll the user in their ERP.
36 37 38 |
# File 'lib/lockstep_sdk/models/provisioning_model.rb', line 36 def erp @erp end |
#full_name ⇒ String
Returns The full name of the new user.
32 33 34 |
# File 'lib/lockstep_sdk/models/provisioning_model.rb', line 32 def full_name @full_name end |
Instance Method Details
#as_json(options = {}) ⇒ object
Returns This object as a JSON key-value structure.
40 41 42 43 44 45 |
# File 'lib/lockstep_sdk/models/provisioning_model.rb', line 40 def as_json(={}) { 'fullName' => @full_name, 'erp' => @erp, } end |
#to_json(*options) ⇒ String
Returns This object converted to a JSON string.
49 50 51 |
# File 'lib/lockstep_sdk/models/provisioning_model.rb', line 49 def to_json(*) "[#{as_json(*).to_json(*)}]" end |