Class: ProfilesAccountingContactsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/lockstep_sdk/clients/profiles_accounting_contacts_client.rb

Instance Method Summary collapse

Constructor Details

#initialize(connection) ⇒ ProfilesAccountingContactsClient

Initialize the ProfilesAccountingContactsClient class with an API client instance.

Parameters:

  • connection (LockstepApi)

    The API client object for this connection



22
23
24
# File 'lib/lockstep_sdk/clients/profiles_accounting_contacts_client.rb', line 22

def initialize(connection)
    @connection = connection
end

Instance Method Details

#create_accounting_profile_contacts(body:) ⇒ Object

Creates one or more Accounting Profile Contacts from a given model.

An Accounting Profile Contact has a link to a Contact that is associated with your company’s Accounting Profile. These Contacts are secondary contacts to the primary that is on the profile.

Parameters:

  • body (AccountingProfileContactModel)

    The Accounting Profile Contacts to create



55
56
57
58
# File 'lib/lockstep_sdk/clients/profiles_accounting_contacts_client.rb', line 55

def create_accounting_profile_contacts(body:)
    path = "/api/v1/profiles/accounting/contacts"
    @connection.request(:post, path, body, nil)
end

#delete_accounting_profile_contact(id:) ⇒ Object

Delete the Accounting Profile Contact referred to by this unique identifier.

An Accounting Profile Contact has a link to a Contact that is associated with your company’s Accounting Profile. These Contacts are secondary contacts to the primary that is on the profile.

Parameters:

  • id (uuid)

    The unique Lockstep Platform ID number of the Accounting Profile Contact to delete



44
45
46
47
# File 'lib/lockstep_sdk/clients/profiles_accounting_contacts_client.rb', line 44

def delete_accounting_profile_contact(id:)
    path = "/api/v1/profiles/accounting/contacts/#{id}"
    @connection.request(:delete, path, nil, nil)
end

#query_accounting_profile_contacts(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object

Queries Accounting Profile Contacts for this account using the specified filtering, sorting, nested fetch, and pagination rules requested.

More information on querying can be found on the [Searchlight Query Language](developer.lockstep.io/docs/querying-with-searchlight) page on the Lockstep Developer website.

An Accounting Profile Contact has a link to a Contact that is associated with your company’s Accounting Profile. These Contacts are secondary contacts to the primary that is on the profile.

Parameters:



86
87
88
89
90
# File 'lib/lockstep_sdk/clients/profiles_accounting_contacts_client.rb', line 86

def query_accounting_profile_contacts(filter:, include_param:, order:, page_size:, page_number:)
    path = "/api/v1/profiles/accounting/contacts/query"
    params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number}
    @connection.request(:get, path, nil, params)
end

#retrieve_accounting_profile_contact(id:) ⇒ Object

Retrieves the Accounting Profile Contact specified by this unique identifier, optionally including nested data sets.

A Contact has a link to a Contact that is associated with your company’s Accounting Profile. These Contacts are secondary contacts to the primary that is on the profile.

Parameters:

  • id (uuid)

    The unique Lockstep Platform ID number of this Accounting Profile Contact



33
34
35
36
# File 'lib/lockstep_sdk/clients/profiles_accounting_contacts_client.rb', line 33

def retrieve_accounting_profile_contact(id:)
    path = "/api/v1/profiles/accounting/contacts/#{id}"
    @connection.request(:get, path, nil, nil)
end

#update_accounting_profile_contact(id:, contact_id:) ⇒ Object

Updates an accounting profile contact that matches the specified id with the requested information.

The PATCH method allows you to change specific values on the object while leaving other values alone. As input you should supply a list of field names and new values. If you do not provide the name of a field, that field will remain unchanged. This allows you to ensure that you are only updating the specific fields desired.

An Accounting Profile Contact has a link to a Contact that is associated with your company’s Accounting Profile. These Contacts are secondary contacts to the primary that is on the profile.

Parameters:

  • id (uuid)

    The unique Lockstep Platform ID number of the Accounting Profile Contact to update

  • contact_id (uuid)

    The ID of the contact to link to this Accounting Profile Contact



69
70
71
72
# File 'lib/lockstep_sdk/clients/profiles_accounting_contacts_client.rb', line 69

def update_accounting_profile_contact(id:, contact_id:)
    path = "/api/v1/profiles/accounting/contacts/#{id}/#{contactId}"
    @connection.request(:patch, path, nil, nil)
end