Class: ProfilesCompaniesClient
- Inherits:
-
Object
- Object
- ProfilesCompaniesClient
- Defined in:
- lib/lockstep_sdk/clients/profiles_companies_client.rb
Instance Method Summary collapse
-
#initialize(connection) ⇒ ProfilesCompaniesClient
constructor
Initialize the ProfilesCompaniesClient class with an API client instance.
-
#query_public_company_profiles(filter:, order:, page_size:, page_number:) ⇒ Object
Queries Public Company Profiles.
-
#retrieve_public_company_profile(url_slug:) ⇒ Object
Retrieves the Public Company Profile specified by the public url slug.
Constructor Details
#initialize(connection) ⇒ ProfilesCompaniesClient
Initialize the ProfilesCompaniesClient class with an API client instance.
22 23 24 |
# File 'lib/lockstep_sdk/clients/profiles_companies_client.rb', line 22 def initialize(connection) @connection = connection end |
Instance Method Details
#query_public_company_profiles(filter:, order:, page_size:, page_number:) ⇒ Object
Queries Public Company Profiles
More information on querying can be found on the Searchlight Query Language page on the Lockstep Developer website.
A Public Company Profile makes available the following information:
- Company Name
- Company Logo Url
- Description
- Website
49 50 51 52 53 |
# File 'lib/lockstep_sdk/clients/profiles_companies_client.rb', line 49 def query_public_company_profiles(filter:, order:, page_size:, page_number:) path = "/api/v1/profiles/companies/query" params = {:filter => filter, :order => order, :pageSize => page_size, :pageNumber => page_number} @connection.request(:get, path, nil, params) end |
#retrieve_public_company_profile(url_slug:) ⇒ Object
Retrieves the Public Company Profile specified by the public url slug.
A Public Company Profile makes available the following information:
- Company Name
- Company Logo Url
- Description
- Website
32 33 34 35 |
# File 'lib/lockstep_sdk/clients/profiles_companies_client.rb', line 32 def retrieve_public_company_profile(url_slug:) path = "/api/v1/profiles/companies/#{urlSlug}" @connection.request(:get, path, nil, nil) end |