Class: TranscriptionsClient
- Inherits:
-
Object
- Object
- TranscriptionsClient
- Defined in:
- lib/lockstep_sdk/clients/transcriptions_client.rb
Instance Method Summary collapse
-
#create_transcription_validation_request(body:) ⇒ Object
Creates one Transcription Validation Request with all the associated request items within this account and returns the record as created.
-
#delete_transcription_validation_request(id:) ⇒ Object
Deletes the Transcription Validation Request and all associated items referred to by this unique identifier.
-
#initialize(connection) ⇒ TranscriptionsClient
constructor
Initialize the TranscriptionsClient class with an API client instance.
-
#query_transcription_validation_requests(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object
Queries transcription validation requests transactions for this account using the specified filtering, sorting, nested fetch, and pagination rules requested.
-
#retrieve_transcription_validation_request(id:, include_param:) ⇒ Object
Retrieves the Transcription Validation Request specified by this unique identifier, optionally including nested data sets.
-
#update_transcription_validation_request(id:, body:) ⇒ Object
Updates an existing Transcription Validation Request with the information supplied to this PATCH call.
Constructor Details
#initialize(connection) ⇒ TranscriptionsClient
Initialize the TranscriptionsClient class with an API client instance.
22 23 24 |
# File 'lib/lockstep_sdk/clients/transcriptions_client.rb', line 22 def initialize(connection) @connection = connection end |
Instance Method Details
#create_transcription_validation_request(body:) ⇒ Object
Creates one Transcription Validation Request with all the associated request items within this account and returns the record as created.
A Transcription Validation Request represents a collection of files sent from the client to verify the file type using the machine learning platform Sage AI.
71 72 73 74 |
# File 'lib/lockstep_sdk/clients/transcriptions_client.rb', line 71 def create_transcription_validation_request(body:) path = "/api/v1/Transcriptions/validate" @connection.request(:post, path, body, nil) end |
#delete_transcription_validation_request(id:) ⇒ Object
Deletes the Transcription Validation Request and all associated items referred to by this unique identifier.
A Transcription Validation Request represents a collection of files sent from the client to verify the file type using the machine learning platform Sage AI.
60 61 62 63 |
# File 'lib/lockstep_sdk/clients/transcriptions_client.rb', line 60 def delete_transcription_validation_request(id:) path = "/api/v1/Transcriptions/validate/#{id}" @connection.request(:delete, path, nil, nil) end |
#query_transcription_validation_requests(filter:, include_param:, order:, page_size:, page_number:) ⇒ Object
Queries transcription validation requests transactions for this account using the specified filtering, sorting, nested fetch, and pagination rules requested.
More information on querying can be found on the [Searchlight Query Language](developer.lockstep.io/docs/querying-with-searchlight) page on the Lockstep Developer website.
86 87 88 89 90 |
# File 'lib/lockstep_sdk/clients/transcriptions_client.rb', line 86 def query_transcription_validation_requests(filter:, include_param:, order:, page_size:, page_number:) path = "/api/v1/Transcriptions/validate/query" params = {:filter => filter, :include => include_param, :order => order, :pageSize => page_size, :pageNumber => page_number} @connection.request(:get, path, nil, params) end |
#retrieve_transcription_validation_request(id:, include_param:) ⇒ Object
Retrieves the Transcription Validation Request specified by this unique identifier, optionally including nested data sets.
A Transcription Validation Request represents a collection of files sent from the client to verify the file type using the machine learning platform Sage AI.
34 35 36 37 38 |
# File 'lib/lockstep_sdk/clients/transcriptions_client.rb', line 34 def retrieve_transcription_validation_request(id:, include_param:) path = "/api/v1/Transcriptions/validate/#{id}" params = {:include => include_param} @connection.request(:get, path, nil, params) end |
#update_transcription_validation_request(id:, body:) ⇒ Object
Updates an existing Transcription Validation Request with the information supplied to this PATCH call.
The PATCH method allows you to change specific values on the object while leaving other values alone. As input you should supply a list of field names and new values. If you do not provide the name of a field, that field will remain unchanged. This allows you to ensure that you are only updating the specific fields desired.
A Transcription Validation Request represents a collection of files sent from the client to verify the file type using the machine learning platform Sage AI.
49 50 51 52 |
# File 'lib/lockstep_sdk/clients/transcriptions_client.rb', line 49 def update_transcription_validation_request(id:, body:) path = "/api/v1/Transcriptions/validate/#{id}" @connection.request(:patch, path, body.to_camelback_keys.to_json, nil) end |